@@ -31,9 +31,6 @@ time_bins <- function(x, middle = TRUE) {
 #' @importFrom stats IQR
 time_bins.sir <- function(x, middle = TRUE) {
   sir <- x
-  if (!inherits(sir, "sir")) {
-    stop("This is not an SIR model output")
-  }
 
   big.time <- unlist(sapply(sir, "[[", "times"))
   medlen <- median(sapply(lapply(sir, "[[", "times"), length))
@@ -54,9 +51,6 @@ time_bins.sir <- function(x, middle = TRUE) {
 #' @export
 median.sir <- function(x, na.rm = FALSE, ...) {
   sir <- x
-  if (!inherits(sir, "sir")) {
-    stop("This is not an SIR model output")
-  }
   times <- unlist(sapply(sir, "[[", "times"))
   big.N.NS <- unlist(sapply(sir, "[[", "NS"))
   big.N.NI <- unlist(sapply(sir, "[[", "NI"))
@@ -74,9 +68,6 @@ median.sir <- function(x, na.rm = FALSE, ...) {
 #' @export
 quantile.sir <- function(x, comp = c("NI", "NS", "NR"), prob, ...) {
   sir <- x
-  if (!inherits(sir, "sir")) {
-    stop("This is not an SIR model output")
-  }
   comp <- toupper(igraph.match.arg(comp))
   times <- unlist(sapply(sir, "[[", "times"))
   big.N <- unlist(sapply(sir, function(x) {
@@ -102,8 +93,6 @@ quantile.sir <- function(x, comp = c("NI", "NS", "NR"), prob, ...) {
 # Outputs:  None.  Just produces the plot of all compartment curves,
 #           with median and quantiles.
 
-
-
 #' Plotting the results on multiple SIR model runs
 #'
 #' This function can conveniently plot the results of multiple SIR model
@@ -135,7 +124,7 @@ quantile.sir <- function(x, comp = c("NI", "NS", "NR"), prob, ...) {
 #' @param \dots Additional arguments are passed to [plot()], that is run
 #'   before any of the curves are added, to create the figure.
 #' @return Nothing.
-#' @author Eric Kolaczyk (<http://math.bu.edu/people/kolaczyk/>) and Gabor
+#' @author Eric Kolaczyk (<https://kolaczyk.github.io/>) and Gabor
 #' Csardi \email{csardi.gabor@@gmail.com}.
 #' @seealso [sir()] for running the actual simulation.
 #' @references Bailey, Norman T. J. (1975). The mathematical theory of
@@ -151,19 +140,28 @@ quantile.sir <- function(x, comp = c("NI", "NS", "NR"), prob, ...) {
 #' sm <- sir(g, beta = 5, gamma = 1)
 #' plot(sm)
 #'
-plot.sir <- function(x, comp = c("NI", "NS", "NR"),
-                     median = TRUE, quantiles = c(0.1, 0.9), color = NULL,
-                     median_color = NULL, quantile_color = NULL,
-                     lwd.median = 2, lwd.quantile = 2, lty.quantile = 3,
-                     xlim = NULL, ylim = NULL, xlab = "Time", ylab = NULL, ...) {
+plot.sir <- function(
+  x,
+  comp = c("NI", "NS", "NR"),
+  median = TRUE,
+  quantiles = c(0.1, 0.9),
+  color = NULL,
+  median_color = NULL,
+  quantile_color = NULL,
+  lwd.median = 2,
+  lwd.quantile = 2,
+  lty.quantile = 3,
+  xlim = NULL,
+  ylim = NULL,
+  xlab = "Time",
+  ylab = NULL,
+  ...
+) {
   sir <- x
 
-  if (!inherits(sir, "sir")) {
-    stop("This is not an SIR model output")
-  }
   comp <- toupper(igraph.match.arg(comp))
   if (!all(quantiles >= 0 & quantiles <= 1)) {
-    stop("Quantiles should be in [0,1]")
+    cli::cli_abort("All {.arg quantiles} should be in [0,1].")
   }
 
   if (is.null(color)) {
@@ -178,12 +176,8 @@ plot.sir <- function(x, comp = c("NI", "NS", "NR"),
   quantile_color <- rep(quantile_color, length.out = length(quantiles))
 
   ns <- length(sir)
-  if (is.null(xlim)) {
-    xlim <- c(0, max(sapply(sir, function(x) max(x$times))))
-  }
-  if (is.null(ylim)) {
-    ylim <- c(0, max(sapply(sir, function(x) max(x[[comp]]))))
-  }
+  xlim <- xlim %||% c(0, max(sapply(sir, function(x) max(x$times))))
+  ylim <- ylim %||% c(0, max(sapply(sir, function(x) max(x[[comp]]))))
 
   ## Generate the plot, first with individual curves, and then
   ## adding median and quantile curves.
@@ -201,7 +195,16 @@ plot.sir <- function(x, comp = c("NI", "NS", "NR"),
   }
 
   # Plot the stochastic curves individually.
-  plot(0, 0, type = "n", xlim = xlim, ylim = ylim, xlab = xlab, ylab = ylab, ...)
+  plot(
+    0,
+    0,
+    type = "n",
+    xlim = xlim,
+    ylim = ylim,
+    xlab = xlab,
+    ylab = ylab,
+    ...
+  )
   lapply(seq_along(sir), function(i) {
     lines(sir[[i]]$times, sir[[i]][[comp]], col = color[1])
   })
@@ -211,16 +214,23 @@ plot.sir <- function(x, comp = c("NI", "NS", "NR"),
     time.bin <- time_bins(sir, middle = TRUE)
   }
   if (median) {
-    lines(time.bin, median(sir)[[comp]],
+    lines(
+      time.bin,
+      median(sir)[[comp]],
       type = "l",
-      lwd = lwd.median, col = median_color
+      lwd = lwd.median,
+      col = median_color
     )
   }
   for (i in seq_along(quantiles)) {
     my.ql <- quantile(sir, comp, quantiles[i])
-    lines(time.bin, my.ql,
-      type = "l", lty = lty.quantile,
-      lwd = lwd.quantile, col = quantile_color[i]
+    lines(
+      time.bin,
+      my.ql,
+      type = "l",
+      lty = lty.quantile,
+      lwd = lwd.quantile,
+      col = quantile_color[i]
     )
   }
 
