@@ -1,3 +1,301 @@
+#' Vertex connectivity
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `vertex.disjoint.paths()` was renamed to [vertex_disjoint_paths()] to create a more
+#' consistent API.
+#' @inheritParams vertex_disjoint_paths
+#' @keywords internal
+#' @export
+vertex.disjoint.paths <- function(graph, source = NULL, target = NULL) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "vertex.disjoint.paths()",
+    "vertex_disjoint_paths()"
+  )
+  vertex_disjoint_paths(graph = graph, source = source, target = target)
+} # nocov end
+
+#' Vertex connectivity
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `vertex.connectivity()` was renamed to [vertex_connectivity()] to create a more
+#' consistent API.
+#' @inheritParams vertex_connectivity
+#' @keywords internal
+#' @export
+vertex.connectivity <- function(
+  graph,
+  source = NULL,
+  target = NULL,
+  checks = TRUE
+) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "vertex.connectivity()",
+    "vertex_connectivity()"
+  )
+  vertex_connectivity(
+    graph = graph,
+    source = source,
+    target = target,
+    checks = checks
+  )
+} # nocov end
+
+#' List all minimum \((s,t)\)-cuts of a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `stMincuts()` was renamed to [st_min_cuts()] to create a more
+#' consistent API.
+#' @inheritParams st_min_cuts
+#' @keywords internal
+#' @export
+stMincuts <- function(graph, source, target, capacity = NULL) {
+  # nocov start
+  lifecycle::deprecate_soft("2.0.0", "stMincuts()", "st_min_cuts()")
+  st_min_cuts(
+    graph = graph,
+    source = source,
+    target = target,
+    capacity = capacity
+  )
+} # nocov end
+
+#' List all (s,t)-cuts of a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `stCuts()` was renamed to [st_cuts()] to create a more
+#' consistent API.
+#' @inheritParams st_cuts
+#' @keywords internal
+#' @export
+stCuts <- function(graph, source, target) {
+  # nocov start
+  lifecycle::deprecate_soft("2.0.0", "stCuts()", "st_cuts()")
+  st_cuts(graph = graph, source = source, target = target)
+} # nocov end
+
+#' Minimum size vertex separators
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `minimum.size.separators()` was renamed to [min_separators()] to create a more
+#' consistent API.
+#' @inheritParams min_separators
+#' @keywords internal
+#' @export
+minimum.size.separators <- function(graph) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "minimum.size.separators()",
+    "min_separators()"
+  )
+  min_separators(graph = graph)
+} # nocov end
+
+#' Minimum size vertex separators
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `minimal.st.separators()` was renamed to [min_st_separators()] to create a more
+#' consistent API.
+#' @inheritParams min_st_separators
+#' @keywords internal
+#' @export
+minimal.st.separators <- function(graph) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "minimal.st.separators()",
+    "min_st_separators()"
+  )
+  min_st_separators(graph = graph)
+} # nocov end
+
+#' Vertex separators
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `is.separator()` was renamed to [is_separator()] to create a more
+#' consistent API.
+#' @inheritParams is_separator
+#' @keywords internal
+#' @export
+is.separator <- function(graph, candidate) {
+  # nocov start
+  lifecycle::deprecate_soft("2.0.0", "is.separator()", "is_separator()")
+  is_separator(graph = graph, candidate = candidate)
+} # nocov end
+
+#' Minimal vertex separators
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `is.minimal.separator()` was renamed to [is_min_separator()] to create a more
+#' consistent API.
+#' @inheritParams is_min_separator
+#' @keywords internal
+#' @export
+is.minimal.separator <- function(graph, candidate) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "is.minimal.separator()",
+    "is_min_separator()"
+  )
+  is_min_separator(graph = graph, candidate = candidate)
+} # nocov end
+
+#' Minimum cut in a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `graph.mincut()` was renamed to [min_cut()] to create a more
+#' consistent API.
+#' @inheritParams min_cut
+#' @keywords internal
+#' @export
+graph.mincut <- function(
+  graph,
+  source = NULL,
+  target = NULL,
+  capacity = NULL,
+  value.only = TRUE
+) {
+  # nocov start
+  lifecycle::deprecate_soft("2.0.0", "graph.mincut()", "min_cut()")
+  min_cut(
+    graph = graph,
+    source = source,
+    target = target,
+    capacity = capacity,
+    value.only = value.only
+  )
+} # nocov end
+
+#' Maximum flow in a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `graph.maxflow()` was renamed to [max_flow()] to create a more
+#' consistent API.
+#' @inheritParams max_flow
+#' @keywords internal
+#' @export
+graph.maxflow <- function(graph, source, target, capacity = NULL) {
+  # nocov start
+  lifecycle::deprecate_soft("2.0.0", "graph.maxflow()", "max_flow()")
+  max_flow(graph = graph, source = source, target = target, capacity = capacity)
+} # nocov end
+
+#' Edge connectivity
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `graph.adhesion()` was renamed to [adhesion()] to create a more
+#' consistent API.
+#' @inheritParams adhesion
+#' @keywords internal
+#' @export
+graph.adhesion <- function(graph, checks = TRUE) {
+  # nocov start
+  lifecycle::deprecate_soft("2.0.0", "graph.adhesion()", "adhesion()")
+  adhesion(graph = graph, checks = checks)
+} # nocov end
+
+#' Edge connectivity
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `edge.disjoint.paths()` was renamed to [edge_connectivity()] to create a more
+#' consistent API.
+#' @inheritParams edge_connectivity
+#' @keywords internal
+#' @export
+edge.disjoint.paths <- function(
+  graph,
+  source = NULL,
+  target = NULL,
+  checks = TRUE
+) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "edge.disjoint.paths()",
+    "edge_connectivity()"
+  )
+  edge_connectivity(
+    graph = graph,
+    source = source,
+    target = target,
+    checks = checks
+  )
+} # nocov end
+
+#' Edge connectivity
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `edge.connectivity()` was renamed to [edge_connectivity()] to create a more
+#' consistent API.
+#' @inheritParams edge_connectivity
+#' @keywords internal
+#' @export
+edge.connectivity <- function(
+  graph,
+  source = NULL,
+  target = NULL,
+  checks = TRUE
+) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "edge.connectivity()",
+    "edge_connectivity()"
+  )
+  edge_connectivity(
+    graph = graph,
+    source = source,
+    target = target,
+    checks = checks
+  )
+} # nocov end
+
+#' Dominator tree
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `dominator.tree()` was renamed to [dominator_tree()] to create a more
+#' consistent API.
+#' @inheritParams dominator_tree
+#' @keywords internal
+#' @export
+dominator.tree <- function(graph, root, mode = c("out", "in", "all", "total")) {
+  # nocov start
+  lifecycle::deprecate_soft("2.0.0", "dominator.tree()", "dominator_tree()")
+  dominator_tree(graph = graph, root = root, mode = mode)
+} # nocov end
 #   IGraph R package
 #   Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
 #   334 Harvard street, Cambridge, MA 02139 USA
@@ -42,7 +340,6 @@
 #' For undirected graphs the Stoer-Wagner algorithm (see reference below) is
 #' used to calculate the minimum cut.
 #'
-#' @aliases graph.mincut
 #' @param graph The input graph.
 #' @param source The id of the source vertex.
 #' @param target The id of the target vertex (sometimes also called sink).
@@ -54,16 +351,26 @@
 #' @return For `min_cut()` a nuieric constant, the value of the minimum
 #'   cut, except if `value.only = FALSE`. In this case a named list with
 #'   components:
-#'   \item{value}{Numeric scalar, the cut value.}
-#'   \item{cut}{Numeric vector, the edges in the cut.}
-#'   \item{partition1}{The vertices in the first partition after the cut
-#'     edges are removed. Note that these vertices might be actually in
-#'     different components (after the cut edges are removed), as the graph
-#'     may fall apart into more than two components.}
-#'   \item{partition2}{The vertices in the second partition
-#'     after the cut edges are removed. Note that these vertices might be
-#'     actually in different components (after the cut edges are removed), as
-#'     the graph may fall apart into more than two components.}
+#'   \describe{
+#'     \item{value}{
+#'       Numeric scalar, the cut value.
+#'     }
+#'     \item{cut}{
+#'       Numeric vector, the edges in the cut.
+#'     }
+#'     \item{partition1}{
+#'       The vertices in the first partition after the cut edges are removed.
+#'       Note that these vertices might be actually in different components
+#'       (after the cut edges are removed),
+#'       as the graph may fall apart into more than two components.
+#'     }
+#'     \item{partition2}{
+#'       The vertices in the second partition after the cut edges are removed.
+#'       Note that these vertices might be actually in different components
+#'       (after the cut edges are removed),
+#'       as the graph may fall apart into more than two components.
+#'     }
+#'   }
 #' @references M. Stoer and F. Wagner: A simple min-cut algorithm,
 #' *Journal of the ACM*, 44 585-591, 1997.
 #' @examples
@@ -76,29 +383,32 @@
 #' min_cut(g2, value.only = FALSE)
 #' @family flow
 #' @export
-min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.only = TRUE) {
+min_cut <- function(
+  graph,
+  source = NULL,
+  target = NULL,
+  capacity = NULL,
+  value.only = TRUE
+) {
   ensure_igraph(graph)
-  if (is.null(capacity)) {
-    if ("capacity" %in% edge_attr_names(graph)) {
-      capacity <- E(graph)$capacity
-    }
+  if (is.null(capacity) && "capacity" %in% edge_attr_names(graph)) {
+    capacity <- E(graph)$capacity
   }
-  if (length(source) == 0) {
-    source <- NULL
-  }
-  if (length(target) == 0) {
-    target <- NULL
-  }
-  if (is.null(source) && !is.null(target) ||
-    is.null(target) && !is.null(source)) {
-    stop("Please give both source and target or neither")
+
+  if (xor(is.null(source), is.null(target))) {
+    cli::cli_abort(c(
+      "{.arg source} and {.arg target} must not be specified at the same time.",
+      i = "Specify either {.arg source} or {.arg target} or neither."
+    ))
   }
+
   if (!is.null(capacity)) {
     capacity <- as.numeric(capacity)
   }
 
   value.only <- as.logical(value.only)
   on.exit(.Call(R_igraph_finalizer))
+
   if (is.null(target) && is.null(source)) {
     if (value.only) {
       res <- .Call(R_igraph_mincut_value, graph, capacity)
@@ -117,15 +427,19 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
   } else {
     if (value.only) {
       res <- .Call(
-        R_igraph_st_mincut_value, graph,
+        R_igraph_st_mincut_value,
+        graph,
         as_igraph_vs(graph, source) - 1,
-        as_igraph_vs(graph, target) - 1, capacity
+        as_igraph_vs(graph, target) - 1,
+        capacity
       )
     } else {
       res <- .Call(
-        R_igraph_st_mincut, graph,
+        R_igraph_st_mincut,
+        graph,
         as_igraph_vs(graph, source) - 1,
-        as_igraph_vs(graph, target) - 1, capacity
+        as_igraph_vs(graph, target) - 1,
+        capacity
       )
       # No need to add +1 here; R_igraph_st_mincut() is autogenerated and
       # adds +1 already
@@ -141,19 +455,22 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
 }
 
 
-
 #' Vertex connectivity
 #'
 #' The vertex connectivity of a graph or two vertices, this is recently also
 #' called group cohesion.
 #'
 #' The vertex connectivity of two vertices (`source` and `target`) in
-#' a directed graph is the minimum number of vertices needed to remove from the
-#' graph to eliminate all (directed) paths from `source` to `target`.
+#' a graph is the minimum number of vertices that must be deleted to
+#' eliminate all (directed) paths from `source` to `target`.
 #' `vertex_connectivity()` calculates this quantity if both the
 #' `source` and `target` arguments are given and they're not
 #' `NULL`.
 #'
+#' The vertex connectivity of a pair is the same as the number
+#' of different (i.e. node-independent) paths from source to
+#' target, assuming no direct edges between them.
+#'
 #' The vertex connectivity of a graph is the minimum vertex connectivity of all
 #' (ordered) pairs of vertices in the graph. In other words this is the minimum
 #' number of vertices needed to remove to make the graph not strongly
@@ -177,7 +494,7 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
 #' precisely `vertex_connectivity()` is the most general, the other two are
 #' included only for the ease of using more descriptive function names.
 #'
-#' @aliases vertex.connectivity vertex.disjoint.paths cohesion graph.cohesion
+#' @aliases cohesion
 #' @param graph,x The input graph.
 #' @param source The id of the source vertex, for `vertex_connectivity()` it
 #'   can be `NULL`, see details below.
@@ -190,7 +507,8 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
 #'   perform these checks, as they can be done quickly compared to the
 #'   connectivity calculation itself.  They were suggested by Peter McMahan,
 #'   thanks Peter.
-#' @param ... Ignored.
+#' @param ... Additional arguments passed to methods. Not used by `vertex_connectivity()`
+#'   directly but may be used by other methods that implement `cohesion()`.
 #' @return A scalar real value.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @references White, Douglas R and Frank Harary 2001. The Cohesiveness of
@@ -210,41 +528,44 @@ min_cut <- function(graph, source = NULL, target = NULL, capacity = NULL, value.
 #' vertex_disjoint_paths(g2, 100, 1)
 #'
 #' g <- sample_gnp(50, 5 / 50)
-#' g <- as.directed(g)
+#' g <- as_directed(g)
 #' g <- induced_subgraph(g, subcomponent(g, 1))
 #' cohesion(g)
 #'
-vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TRUE) {
+vertex_connectivity <- function(
+  graph,
+  source = NULL,
+  target = NULL,
+  checks = TRUE
+) {
   ensure_igraph(graph)
 
-  if (length(source) == 0) {
-    source <- NULL
-  }
-  if (length(target) == 0) {
-    target <- NULL
-  }
-
   if (is.null(source) && is.null(target)) {
     on.exit(.Call(R_igraph_finalizer))
     .Call(R_igraph_vertex_connectivity, graph, as.logical(checks))
   } else if (!is.null(source) && !is.null(target)) {
     on.exit(.Call(R_igraph_finalizer))
     .Call(
-      R_igraph_st_vertex_connectivity, graph, as_igraph_vs(graph, source) - 1,
+      R_igraph_st_vertex_connectivity,
+      graph,
+      as_igraph_vs(graph, source) - 1,
       as_igraph_vs(graph, target) - 1
     )
   } else {
-    stop("either give both source and target or neither")
+    cli::cli_abort(c(
+      "{.arg source} and {.arg target} must not be specified at the same time.",
+      i = "Specify either {.arg source} or {.arg target} or neither."
+    ))
   }
 }
 
 
-
 #' Edge connectivity
 #'
 #' The edge connectivity of a graph or two vertices, this is recently also
 #' called group adhesion.
 #'
+#' @section `edge_connectivity()` Edge connectivity:
 #' The edge connectivity of a pair of vertices (`source` and
 #' `target`) is the minimum number of edges needed to remove to eliminate
 #' all (directed) paths from `source` to `target`.
@@ -256,19 +577,34 @@ vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TR
 #' calculates this quantity if neither the `source` nor the `target`
 #' arguments are given (i.e. they are both `NULL`).
 #'
+#' @section `edge_disjoint_paths()` The maximum number of edge-disjoint paths between two vertices:
+#' A set of paths between two vertices is called edge-disjoint if they do not
+#' share any edges. The maximum number of edge-disjoint paths are calculated
+#' by this function using maximum flow techniques. Directed paths are
+#' considered in directed graphs.
+#'
+#'
 #' A set of edge disjoint paths between two vertices is a set of paths between
 #' them containing no common edges. The maximum number of edge disjoint paths
 #' between two vertices is the same as their edge connectivity.
 #'
+#' When there are no direct edges between the source and the target, the number
+#' of vertex-disjoint paths is the same as the vertex connectivity of
+#' the two vertices. When some edges are present, each one of them
+#' contributes one extra path.
+#'
+#' @section `adhesion()` Adhesion of a graph:
 #' The adhesion of a graph is the minimum number of edges needed to remove to
 #' obtain a graph which is not strongly connected. This is the same as the edge
 #' connectivity of the graph.
 #'
+#' @section All three functions:
 #' The three functions documented on this page calculate similar properties,
 #' more precisely the most general is `edge_connectivity()`, the others are
 #' included only for having more descriptive function names.
 #'
-#' @aliases edge.connectivity graph.adhesion edge.disjoint.paths
+#'
+
 #' @param graph The input graph.
 #' @param source The id of the source vertex, for `edge_connectivity()` it
 #'   can be `NULL`, see details below.
@@ -283,8 +619,9 @@ vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TR
 #'   thanks Peter.
 #' @return A scalar real value.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
-#' @references Douglas R. White and Frank Harary: The cohesiveness of blocks in
-#' social networks: node connectivity and conditional density, TODO: citation
+#' @references Douglas R. White and Frank Harary (2001): The cohesiveness of blocks in
+#' social networks: node connectivity and conditional density,
+#' Sociological Methodology, vol. 31, 2001, pp. 305–59.
 #' @family flow
 #' @export
 #' @keywords graphs
@@ -297,50 +634,50 @@ vertex_connectivity <- function(graph, source = NULL, target = NULL, checks = TR
 #' edge_disjoint_paths(g2, 100, 1)
 #'
 #' g <- sample_gnp(50, 5 / 50)
-#' g <- as.directed(g)
+#' g <- as_directed(g)
 #' g <- induced_subgraph(g, subcomponent(g, 1))
 #' adhesion(g)
 #'
-edge_connectivity <- function(graph, source = NULL, target = NULL, checks = TRUE) {
+edge_connectivity <- function(
+  graph,
+  source = NULL,
+  target = NULL,
+  checks = TRUE
+) {
   ensure_igraph(graph)
 
-  if (length(source) == 0) {
-    source <- NULL
-  }
-  if (length(target) == 0) {
-    target <- NULL
-  }
-
   if (is.null(source) && is.null(target)) {
     on.exit(.Call(R_igraph_finalizer))
     .Call(R_igraph_edge_connectivity, graph, as.logical(checks))
   } else if (!is.null(source) && !is.null(target)) {
     on.exit(.Call(R_igraph_finalizer))
     .Call(
-      R_igraph_st_edge_connectivity, graph,
-      as_igraph_vs(graph, source) - 1, as_igraph_vs(graph, target) - 1
+      R_igraph_st_edge_connectivity,
+      graph,
+      as_igraph_vs(graph, source) - 1,
+      as_igraph_vs(graph, target) - 1
     )
   } else {
-    stop("either give both source and target or neither")
+    cli::cli_abort(c(
+      "{.arg source} and {.arg target} must not be specified at the same time.",
+      i = "Specify either {.arg source} or {.arg target} or neither."
+    ))
   }
 }
 
 #' @rdname edge_connectivity
 #' @export
-edge_disjoint_paths <- function(graph, source, target) {
+edge_disjoint_paths <- function(graph, source = NULL, target = NULL) {
   ensure_igraph(graph)
-
-  if (length(source) == 0) {
-    source <- NULL
+  if (is.null(source) || is.null(target)) {
+    cli::cli_abort("Both source and target must be given")
   }
-  if (length(target) == 0) {
-    target <- NULL
-  }
-
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_edge_disjoint_paths, graph,
-    as_igraph_vs(graph, source) - 1, as_igraph_vs(graph, target) - 1
+    R_igraph_edge_disjoint_paths,
+    graph,
+    as_igraph_vs(graph, source) - 1,
+    as_igraph_vs(graph, target) - 1
   )
 }
 
@@ -348,17 +685,15 @@ edge_disjoint_paths <- function(graph, source, target) {
 #' @export
 vertex_disjoint_paths <- function(graph, source = NULL, target = NULL) {
   ensure_igraph(graph)
-
-  if (length(source) == 0) {
-    source <- NULL
-  }
-  if (length(target) == 0) {
-    target <- NULL
+  if (is.null(source) || is.null(target)) {
+    cli::cli_abort("Both source and target must be given")
   }
 
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_vertex_disjoint_paths, graph, as_igraph_vs(graph, source) - 1,
+    R_igraph_vertex_disjoint_paths,
+    graph,
+    as_igraph_vs(graph, source) - 1,
     as_igraph_vs(graph, target) - 1
   )
 }
@@ -391,17 +726,22 @@ cohesion.igraph <- function(x, checks = TRUE, ...) {
 #' removing these edges from \eqn{G} there is no directed path from \eqn{s} to
 #' \eqn{t}.
 #'
-#' @aliases stCuts
 #' @param graph The input graph. It must be directed.
 #' @param source The source vertex.
 #' @param target The target vertex.
-#' @return A list with entries: \item{cuts}{A list of numeric vectors
-#'   containing edge ids. Each vector is an \eqn{(s,t)}-cut.}
-#'   \item{partition1s}{A list of numeric vectors containing vertex ids, they
-#'   correspond to the edge cuts. Each vertex set is a generator of the
-#'   corresponding cut, i.e. in the graph \eqn{G=(V,E)}, the vertex set \eqn{X}
-#'   and its complementer \eqn{V-X}, generates the cut that contains exactly the
-#'   edges that go from \eqn{X} to \eqn{V-X}.}
+#' @return A list with entries:
+#'   \describe{
+#'     \item{cuts}{
+#'       A list of numeric vectors containing edge ids.
+#'       Each vector is an \eqn{(s,t)}-cut.
+#'     }
+#'     \item{partition1s}{
+#'       A list of numeric vectors containing vertex ids, they correspond to the edge cuts.
+#'       Each vertex set is a generator of the corresponding cut, i.e. in the graph \eqn{G=(V,E)},
+#'       the vertex set \eqn{X} and its complementer \eqn{V-X},
+#'       generates the cut that contains exactly the edges that go from \eqn{X} to \eqn{V-X}.
+#'     }
+#'   }
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @references JS Provan and DR Shier: A Paradigm for listing (s,t)-cuts in
 #' graphs, *Algorithmica* 15, 351--372, 1996.
@@ -420,6 +760,7 @@ cohesion.igraph <- function(x, checks = TRUE, ...) {
 #' st_cuts(g2, source = "s", target = "t")
 #' @family flow
 #' @export
+#' @cdocs igraph_all_st_cuts
 st_cuts <- all_st_cuts_impl
 
 
@@ -439,7 +780,6 @@ st_cuts <- all_st_cuts_impl
 #'
 #' An \eqn{(s,t)}-cut is minimum if it is of the smallest possible size.
 #'
-#' @aliases stMincuts
 #' @param graph The input graph. It must be directed.
 #' @param source The id of the source vertex.
 #' @param target The id of the target vertex.
@@ -448,14 +788,22 @@ st_cuts <- all_st_cuts_impl
 #'   attribute defines the edge capacities. For forcing unit edge capacities,
 #'   even for graphs that have a `weight` edge attribute, supply `NA`
 #'   here.
-#' @return A list with entries: \item{value}{Numeric scalar, the size of the
-#'   minimum cut(s).} \item{cuts}{A list of numeric vectors containing edge ids.
-#'   Each vector is a minimum \eqn{(s,t)}-cut.} \item{partition1s}{A list of
-#'   numeric vectors containing vertex ids, they correspond to the edge cuts.
-#'   Each vertex set is a generator of the corresponding cut, i.e. in the graph
-#'   \eqn{G=(V,E)}, the vertex set \eqn{X} and its complementer \eqn{V-X},
-#'   generates the cut that contains exactly the edges that go from \eqn{X} to
-#'   \eqn{V-X}.}
+#' @return A list with entries:
+#'   \describe{
+#'     \item{value}{
+#'       Numeric scalar, the size of the minimum cut(s).
+#'     }
+#'     \item{cuts}{
+#'       A list of numeric vectors containing edge ids. Each vector is a minimum \eqn{(s,t)}-cut.
+#'     }
+#'     \item{partition1s}{
+#'       A list of numeric vectors containing vertex ids,
+#'       they correspond to the edge cuts.
+#'       Each vertex set is a generator of the corresponding cut, i.e. in the graph \eqn{G=(V,E)},
+#'       the vertex set \eqn{X} and its complementer \eqn{V-X},
+#'       generates the cut that contains exactly the edges that go from \eqn{X} to \eqn{V-X}.
+#'     }
+#'   }
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @references JS Provan and DR Shier: A Paradigm for listing (s,t)-cuts in
 #' graphs, *Algorithmica* 15, 351--372, 1996.
@@ -470,6 +818,7 @@ st_cuts <- all_st_cuts_impl
 #' st_min_cuts(g, source = "s", target = "t")
 #' @family flow
 #' @export
+#' @cdocs igraph_all_st_mincuts
 st_min_cuts <- all_st_mincuts_impl
 
 
@@ -492,7 +841,6 @@ st_min_cuts <- all_st_mincuts_impl
 #' This function implements the Lengauer-Tarjan algorithm to construct the
 #' dominator tree of a directed graph. For details see the reference below.
 #'
-#' @aliases dominator.tree
 #' @param graph A directed graph. If it is not a flowgraph, and it contains
 #'   some vertices not reachable from the root vertex, then these vertices will
 #'   be collected and returned as part of the result.
@@ -501,13 +849,22 @@ st_min_cuts <- all_st_mincuts_impl
 #' @param mode Constant, must be \sQuote{`in`} or \sQuote{`out`}. If
 #'   it is \sQuote{`in`}, then all directions are considered as opposite to
 #'   the original one in the input graph.
-#' @return A list with components: \item{dom}{ A numeric vector giving the
-#'   immediate dominators for each vertex. For vertices that are unreachable from
-#'   the root, it contains `NaN`. For the root vertex itself it contains
-#'   minus one.  } \item{domtree}{ A graph object, the dominator tree. Its vertex
-#'   ids are the as the vertex ids of the input graph. Isolate vertices are the
-#'   ones that are unreachable from the root.  } \item{leftout}{ A numeric vector
-#'   containing the vertex ids that are unreachable from the root.  }
+#' @return A list with components:
+#'   \describe{
+#'     \item{dom}{
+#'       A numeric vector giving the immediate dominators for each vertex.
+#'       For vertices that are unreachable from the root, it contains `NaN`.
+#'       For the root vertex itself it contains minus one.
+#'     }
+#'     \item{domtree}{
+#'       A graph object, the dominator tree.
+#'       Its vertex ids are the as the vertex ids of the input graph.
+#'       Isolate vertices are the ones that are unreachable from the root.
+#'     }
+#'     \item{leftout}{
+#'       A numeric vector containing the vertex ids that are unreachable from the root.
+#'     }
+#'   }
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @references Thomas Lengauer, Robert Endre Tarjan: A fast algorithm for
 #' finding dominators in a flowgraph, *ACM Transactions on Programming
@@ -529,12 +886,15 @@ st_min_cuts <- all_st_mincuts_impl
 #' @export
 dominator_tree <- function(graph, root, mode = c("out", "in", "all", "total")) {
   # Argument checks
- ensure_igraph(graph)
-  root <- as_igraph_vs(graph, root)
-  if (length(root) == 0) {
-    stop("No vertex was specified")
+  ensure_igraph(graph)
+
+  if (missing(root) || is.null(root)) {
+    cli::cli_abort("{.arg root} must be specified.")
   }
-  mode <- switch(igraph.match.arg(mode),
+  root <- as_igraph_vs(graph, root)
+
+  mode <- switch(
+    igraph.match.arg(mode),
     "out" = 1,
     "in" = 2,
     "all" = 3,
@@ -557,17 +917,16 @@ dominator_tree <- function(graph, root, mode = c("out", "in", "all", "total")) {
 
 #' Minimum size vertex separators
 #'
-#' List all vertex sets that are minimal (s,t) separators for some s and t, in
-#' an undirected graph.
+#' List all vertex sets that are minimal \eqn{(s,t)} separators for some
+#' \eqn{s} and \eqn{t}, in an undirected graph.
 #'
 #' A \eqn{(s,t)} vertex separator is a set of vertices, such that after their
 #' removal from the graph, there is no path between \eqn{s} and \eqn{t} in the
 #' graph.
 #'
-#' A \eqn{(s,t)} vertex separator is minimal if none of its subsets is an
-#' \eqn{(s,t)} vertex separator.
+#' A \eqn{(s,t)} vertex separator is minimal if none of its proper subsets is
+#' an \eqn{(s,t)} vertex separator for the same \eqn{s} and \eqn{t}.
 #'
-#' @aliases minimal.st.separators
 #' @param graph The input graph. It may be directed, but edge directions are
 #'   ignored.
 #' @return A list of numeric vectors. Each vector contains a vertex set
@@ -587,7 +946,24 @@ dominator_tree <- function(graph, root, mode = c("out", "in", "all", "total")) {
 #'
 #' chvatal <- make_graph("chvatal")
 #' min_st_separators(chvatal)
+#' # https://github.com/r-lib/roxygen2/issues/1092
+#' @section Note:
+#' Note that the code below returns `{1, 3}` despite its subset `{1}` being a
+#' separator as well. This is because `{1, 3}` is minimal with respect to
+#' separating vertices 2 and 4.
+#'
+#' ```{r, eval=FALSE}
+#' g <- make_graph(~ 0-1-2-3-4-1)
+#' min_st_separators(g)
+#' ```
+#'
+#' ```{r, echo=FALSE}
+#' local_igraph_options(print.id = FALSE)
+#' g <- make_graph(~ 0-1-2-3-4-1)
+#' min_st_separators(g)
+#' ```
 #' @family flow
+#' @cdocs igraph_all_minimal_st_separators
 min_st_separators <- all_minimal_st_separators_impl
 
 
@@ -606,7 +982,6 @@ min_st_separators <- all_minimal_st_separators_impl
 #' the flow is the incoming flow of the `target` vertex. The maximum flow
 #' is the flow of maximum value.
 #'
-#' @aliases graph.maxflow
 #' @param graph The input graph.
 #' @param source The id of the source vertex.
 #' @param target The id of the target vertex (sometimes also called sink).
@@ -614,30 +989,38 @@ min_st_separators <- all_minimal_st_separators_impl
 #'   `NULL` (the default) then the `capacity` edge attribute is used.
 #'   Note that the `weight` edge attribute is not used by this function.
 #' @return A named list with components:
-#'   \item{value}{A numeric scalar, the value of the maximum flow.}
-#'   \item{flow}{A numeric vector, the flow itself, one entry for each
-#'     edge. For undirected graphs this entry is bit trickier, since for
-#'     these the flow direction is not predetermined by the edge
-#'     direction. For these graphs the elements of the this vector can be
-#'     negative, this means that the flow goes from the bigger vertex id to
-#'     the smaller one. Positive values mean that the flow goes from
-#'     the smaller vertex id to the bigger one.}
-#'   \item{cut}{A numeric vector of edge ids, the minimum cut corresponding
-#'     to the maximum flow.}
-#'   \item{partition1}{A numeric vector of vertex ids, the vertices in the
-#'     first partition of the minimum cut corresponding to the maximum
-#'     flow.}
-#'   \item{partition2}{A numeric vector of vertex ids, the vertices in the
-#'     second partition of the minimum cut corresponding to the maximum
-#'     flow.}
-#'   \item{stats}{A list with some statistics from the push-relabel
-#'     algorithm. Five integer values currently: `nopush` is the
-#'     number of push operations, `norelabel` the number of
-#'     relabelings, `nogap` is the number of times the gap heuristics
-#'     was used, `nogapnodes` is the total number of gap nodes omitted
-#'     because of the gap heuristics and `nobfs` is the number of
-#'     times a global breadth-first-search update was performed to assign
-#'     better height (=distance) values to the vertices.}
+#'   \describe{
+#'     \item{value}{
+#'       A numeric scalar, the value of the maximum flow.
+#'     }
+#'     \item{flow}{
+#'       A numeric vector, the flow itself, one entry for each edge.
+#'       For undirected graphs this entry is bit trickier,
+#'       since for these the flow direction is not predetermined by the edge direction.
+#'       For these graphs the elements of the this vector can be negative,
+#'       this means that the flow goes from the bigger vertex id to the smaller one.
+#'       Positive values mean that the flow goes from the smaller vertex id to the bigger one.
+#'     }
+#'     \item{cut}{
+#'       A numeric vector of edge ids, the minimum cut corresponding to the maximum flow.
+#'     }
+#'     \item{partition1}{
+#'       A numeric vector of vertex ids, the vertices in the first partition of the minimum cut corresponding to the maximum flow.
+#'     }
+#'     \item{partition2}{
+#'       A numeric vector of vertex ids, the vertices in the second partition of the minimum cut corresponding to the maximum flow.
+#'     }
+#'     \item{stats}{
+#'       A list with some statistics from the push-relabel algorithm.
+#'       Five integer values currently:
+#'       `nopush` is the number of push operations,
+#'       `norelabel` the number of relabelings,
+#'       `nogap` is the number of times the gap heuristics was used,
+#'       `nogapnodes` is the total number of gap nodes omitted because of the gap heuristics and
+#'       `nobfs` is the number of times a global breadth-first-search update was performed
+#'       to assign better height (=distance) values to the vertices.
+#'     }
+#'   }
 #' @references A. V. Goldberg and R. E. Tarjan: A New Approach to the Maximum
 #' Flow Problem *Journal of the ACM* 35:921-940, 1988.
 #' @examples
@@ -648,21 +1031,18 @@ min_st_separators <- all_minimal_st_separators_impl
 #' max_flow(g1, source = V(g1)["1"], target = V(g1)["2"])
 #' @family flow
 #' @export
+#' @cdocs igraph_maxflow
 max_flow <- maxflow_impl
 
 
-#' Vertex separators
+#' Check whether removing this set of vertices would disconnect the graph.
 #'
-#' Check whether a given set of vertices is a vertex separator.
+#' `is_separator()` determines whether the supplied vertex set is a vertex
+#' separator:
+#' A vertex set \eqn{S} is a separator if there are vertices \eqn{u} and \eqn{v}
+#' in the graph such that all paths between \eqn{u} and \eqn{v} pass
+#' through some vertices in \eqn{S}.
 #'
-#' `is_separator()` decides whether the supplied vertex set is a vertex
-#' separator. A vertex set is a vertex separator if its removal results a
-#' disconnected graph.
-#'
-#' In the special case of a fully connected graph with \eqn{n} vertices, each
-#' set of \eqn{n-1} vertices is considered to be a vertex separator.
-#'
-#' @aliases is.separator
 #' @param graph The input graph. It may be directed, but edge directions are
 #'   ignored.
 #' @param candidate A numeric vector giving the vertex ids of the candidate
@@ -671,7 +1051,16 @@ max_flow <- maxflow_impl
 #'   vertex separator or not.
 #'   lists all vertex separator of minimum size.
 #' @family flow
+#' @examples
+#' ring <- make_ring(4)
+#' min_st_separators(ring)
+#' is_separator(ring, 1)
+#' is_separator(ring, c(1, 3))
+#' is_separator(ring, c(2, 4))
+#' is_separator(ring, c(2, 3))
+#'
 #' @export
+#' @cdocs igraph_is_separator
 is_separator <- is_separator_impl
 
 
@@ -681,12 +1070,8 @@ is_separator <- is_separator_impl
 #'
 #' `is_min_separator()` decides whether the supplied vertex set is a minimal
 #' vertex separator. A minimal vertex separator is a vertex separator, such
-#' that none of its subsets is a vertex separator.
+#' that none of its proper subsets are a vertex separator.
 #'
-#' In the special case of a fully connected graph with \eqn{n} vertices, each
-#' set of \eqn{n-1} vertices is considered to be a vertex separator.
-#'
-#' @aliases is.minimal.separator
 #' @param graph The input graph. It may be directed, but edge directions are
 #'   ignored.
 #' @param candidate A numeric vector giving the vertex ids of the candidate
@@ -724,6 +1109,7 @@ is_separator <- is_separator_impl
 #'
 #' @family flow
 #' @export
+#' @cdocs igraph_is_minimal_separator
 is_min_separator <- is_minimal_separator_impl
 
 
@@ -739,7 +1125,6 @@ is_min_separator <- is_minimal_separator_impl
 #' In the special case of a fully connected input graph with \eqn{n} vertices,
 #' all subsets of size \eqn{n-1} are listed as the result.
 #'
-#' @aliases minimum.size.separators
 #' @param graph The input graph. It may be directed, but edge directions are
 #'   ignored.
 #' @return A list of numeric vectors. Each numeric vector is a vertex
@@ -795,4 +1180,5 @@ is_min_separator <- is_minimal_separator_impl
 #'   John - Gery:Russ:Michael
 #' )
 #' min_separators(camp)
+#' @cdocs igraph_minimum_size_separators
 min_separators <- minimum_size_separators_impl
