@@ -1,15 +1,30 @@
-
 #' Writing the graph to a file in some format
 #'
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `write.graph()` was renamed to `write_graph()` to create a more
+#' `write.graph()` was renamed to [write_graph()] to create a more
 #' consistent API.
 #' @inheritParams write_graph
 #' @keywords internal
 #' @export
-write.graph <- function(graph, file, format = c("edgelist", "pajek", "ncol", "lgl", "graphml", "dimacs", "gml", "dot", "leda"), ...) { # nocov start
+write.graph <- function(
+  graph,
+  file,
+  format = c(
+    "edgelist",
+    "pajek",
+    "ncol",
+    "lgl",
+    "graphml",
+    "dimacs",
+    "gml",
+    "dot",
+    "leda"
+  ),
+  ...
+) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "write.graph()", "write_graph()")
   write_graph(graph = graph, file = file, format = format, ...)
 } # nocov end
@@ -19,12 +34,27 @@ write.graph <- function(graph, file, format = c("edgelist", "pajek", "ncol", "lg
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `read.graph()` was renamed to `read_graph()` to create a more
+#' `read.graph()` was renamed to [read_graph()] to create a more
 #' consistent API.
 #' @inheritParams read_graph
 #' @keywords internal
 #' @export
-read.graph <- function(file, format = c("edgelist", "pajek", "ncol", "lgl", "graphml", "dimacs", "graphdb", "gml", "dl"), ...) { # nocov start
+read.graph <- function(
+  file,
+  format = c(
+    "edgelist",
+    "pajek",
+    "ncol",
+    "lgl",
+    "graphml",
+    "dimacs",
+    "graphdb",
+    "gml",
+    "dl"
+  ),
+  ...
+) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "read.graph()", "read_graph()")
   read_graph(file = file, format = format, ...)
 } # nocov end
@@ -34,14 +64,35 @@ read.graph <- function(file, format = c("edgelist", "pajek", "ncol", "lgl", "gra
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `graph.graphdb()` was renamed to `graph_from_graphdb()` to create a more
+#' `graph.graphdb()` was renamed to [graph_from_graphdb()] to create a more
 #' consistent API.
 #' @inheritParams graph_from_graphdb
 #' @keywords internal
 #' @export
-graph.graphdb <- function(url = NULL, prefix = "iso", type = "r001", nodes = NULL, pair = "A", which = 0, base = "http://cneurocvs.rmki.kfki.hu/graphdb/gzip", compressed = TRUE, directed = TRUE) { # nocov start
+graph.graphdb <- function(
+  url = NULL,
+  prefix = "iso",
+  type = "r001",
+  nodes = NULL,
+  pair = "A",
+  which = 0,
+  base = "http://cneurocvs.rmki.kfki.hu/graphdb/gzip",
+  compressed = TRUE,
+  directed = TRUE
+) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "graph.graphdb()", "graph_from_graphdb()")
-  graph_from_graphdb(url = url, prefix = prefix, type = type, nodes = nodes, pair = pair, which = which, base = base, compressed = compressed, directed = directed)
+  graph_from_graphdb(
+    url = url,
+    prefix = prefix,
+    type = type,
+    nodes = nodes,
+    pair = pair,
+    which = which,
+    base = base,
+    compressed = compressed,
+    directed = directed
+  )
 } # nocov end
 #   IGraph R package
 #   Copyright (C) 2005-2012  Gabor Csardi <csardi.gabor@gmail.com>
@@ -110,7 +161,6 @@ write.graph.fromraw <- function(buffer, file) {
 }
 
 
-
 #' Reading foreign file formats
 #'
 #' The `read_graph()` function is able to read graphs in various
@@ -138,38 +188,116 @@ write.graph.fromraw <- function(buffer, file) {
 #' between the edges, a simple space will also do. Vertex IDs contained in
 #' the file are assumed to start at zero.
 #'
-#' Additional arguments: \describe{ \item{n}{The number of vertices in the
-#' graph. If it is smaller than or equal to the largest integer in the file,
-#' then it is ignored; so it is safe to set it to zero (the default).}
-#' \item{directed}{Logical scalar, whether to create a directed graph. The
-#' default value is `TRUE`.} }
+#' Additional arguments:
+#'   \describe{
+#'     \item{n}{
+#'       The number of vertices in the
+#'       graph. If it is smaller than or equal to the largest integer in the file,
+#'       then it is ignored; so it is safe to set it to zero (the default).
+#'     }
+#'     \item{directed}{
+#'       Logical scalar, whether to create a directed graph. The
+#'       default value is `TRUE`.
+#'     }
+#'   }
 #' @section Pajek format:
 #' Currently igraph only supports Pajek network
 #' files, with a `.net` extension, but not Pajek project files with
 #' a `.paj` extension. Only network data is supported; permutations,
 #' hierarchies, clusters and vectors are not.
 #' @section NCOL format:
-#' Additional arguments: \describe{
-#' \item{predef}{Names of the vertices in the file.
-#' If `character(0)` (the default) is given here
-#' then vertex IDs will be assigned to vertex names in the order of
-#' their appearance in the .ncol file.
-#' If it is not `character(0)` and some unknown vertex names are found
-#' in the .ncol file then new vertex ids will be assigned to them. }
-#' \item{names}{Logical value, if `TRUE` (the default)
-#' the symbolic names of the vertices will be added to the graph
-#' as a vertex attribute called “name”. }
-#' \item{weights}{Whether to add the weights of the edges to the graph
-#' as an edge attribute called “weight”.
-#' `"yes"` adds the weights (even if they are not present in the file,
-#' in this case they are assumed to be zero).
-#' `"no"` does not add any edge attribute.
-#' `"auto"` (the default) adds the attribute if and only
-#' if there is at least one explicit edge weight in the input file. }
-#' \item{directed}{Whether to create a directed graph (default: `FALSE`).
-#' As this format was originally used only for undirected graphs
-#' there is no information in the file about the directedness of the graph.}
+#' Additional arguments:
+#'   \describe{
+#'     \item{predef}{
+#'       Names of the vertices in the file.
+#'       If `character(0)` (the default) is given here
+#'       then vertex IDs will be assigned to vertex names in the order of
+#'       their appearance in the .ncol file.
+#'       If it is not `character(0)` and some unknown vertex names are found
+#'       in the .ncol file then new vertex ids will be assigned to them.
+#'     }
+#'     \item{names}{
+#'       Logical value, if `TRUE` (the default)
+#'       the symbolic names of the vertices will be added to the graph
+#'       as a vertex attribute called “name”.
+#'     }
+#'     \item{weights}{
+#'       Whether to add the weights of the edges to the graph
+#'       as an edge attribute called “weight”.
+#'       `"yes"` adds the weights (even if they are not present in the file,
+#'       in this case they are assumed to be zero).
+#'       `"no"` does not add any edge attribute.
+#'       `"auto"` (the default) adds the attribute if and only
+#'       if there is at least one explicit edge weight in the input file.
+#'     }
+#'     \item{directed}{
+#'       Whether to create a directed graph (default: `FALSE`).
+#'       As this format was originally used only for undirected graphs
+#'       there is no information in the file about the directedness of the graph.
+#'     }
+#'   }
+#' @section GraphML format:
+#' GraphML is an XML-based file format for representing various types of graphs.
+#' Currently only the most basic import functionality is implemented in igraph:
+#' it can read GraphML files without nested graphs and hyperedges.
+#' \describe{
+#'   \item{index}{Integer, specifies which graph to read from a GraphML file
+#'     containing multiple graphs. Defaults to 0 for the first graph.}
 #' }
+#' @section LGL format:
+#' The .lgl format is used by the Large Graph Layout visualization software (<https://lgl.sourceforge.net>), it can describe undirected optionally weighted graphs
+#' \describe{
+#'   \item{names}{Logical, whether to add vertex names as a vertex attribute
+#'     called "name". Default is TRUE.}
+#'      \item{weights}{
+#'         Whether to add the weights of the edges to the graph
+#'         as an edge attribute called “weight”.
+#'         `"yes"` adds the weights (even if they are not present in the file,
+#'         in this case they are assumed to be zero).
+#'         `"no"` does not add any edge attribute.
+#'         `"auto"` (the default) adds the attribute if and only
+#'         if there is at least one explicit edge weight in the input file.
+#'       }
+#'   \item{directed}{Logical, whether to create a directed graph. Default is FALSE.}
+#' }
+#'
+#' @section DIMACS format:
+#' This is a line-oriented text file (ASCII) format.
+#' The first character of each line defines the type of the line.
+#' If the first character is c the line is a comment line and it is ignored.
+#' There is one problem line (p in the file),
+#' it must appear before any node and arc descriptor lines.
+#' The problem line has three fields separated by spaces: the problem type (max or edge),
+#' the number of vertices, and number of edges in the graph. In MAX problems,
+#' exactly two node identification lines are expected (n), one for the source, and one for the target vertex.
+#' These have two fields: the ID of the vertex and the type of the vertex, either s ( = source) or t ( = target).
+#' Arc lines start with a and have three fields: the source vertex, the target vertex and the edge capacity.
+#' In EDGE problems, there may be a node line (n) for each node. It specifies the node index and an
+#'  integer node label. Nodes for which no explicit label was specified will use their index as label.
+#' In EDGE problems, each edge is specified as an edge line (e).
+#' \describe{
+#'   \item{directed}{Logical, whether to create a directed graph. Default is TRUE.}
+#' }
+#'
+#' @section DL format:
+#' This is a simple textual file format used by UCINET.
+#' See <http://www.analytictech.com/networks/dataentry.htm> for examples.
+#' All the forms described here are supported by igraph.
+#' Vertex names and edge weights are also supported and they are added as attributes.
+#' (If an attribute handler is attached.)
+#' Note the specification does not mention whether the format is case sensitive or not.
+#' For igraph DL files are case sensitive, i.e. Larry and larry are not the same.
+#' \describe{
+#'   \item{directed}{Logical, whether to create a directed graph. Default is TRUE.}
+#' }
+#' @section GML format:
+#' GML is a quite general textual format. For the specifics of the implementation, see the linked documentation of the cClibrary.
+#' @section GraphDB format:
+#'  This is a binary format, used in the ARG Graph Database for isomorphism testing. For more information, see <https://mivia.unisa.it/datasets/graph-database/arg-database/>
+#' \describe{
+#'   \item{directed}{Logical, whether to create a directed graph. Default is TRUE.}
+#' }
+#'
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @seealso [write_graph()]
 #' @keywords graphs
@@ -178,20 +306,34 @@ write.graph.fromraw <- function(buffer, file) {
 #' @cdocs igraph_read_graph_dimacs_flow igraph_read_graph_dl igraph_read_graph_edgelist
 #' @cdocs igraph_read_graph_gml igraph_read_graph_graphdb igraph_read_graph_graphml
 #' @cdocs igraph_read_graph_lgl igraph_read_graph_ncol igraph_read_graph_pajek
-read_graph <- function(file, format = c(
-                         "edgelist", "pajek", "ncol", "lgl",
-                         "graphml", "dimacs", "graphdb", "gml", "dl"
-                       ),
-                       ...) {
-  if (!is.character(file) || length(grep("://", file, fixed = TRUE)) > 0 ||
-    length(grep("~", file, fixed = TRUE)) > 0) {
+read_graph <- function(
+  file,
+  format = c(
+    "edgelist",
+    "pajek",
+    "ncol",
+    "lgl",
+    "graphml",
+    "dimacs",
+    "graphdb",
+    "gml",
+    "dl"
+  ),
+  ...
+) {
+  if (
+    !is.character(file) ||
+      length(grep("://", file, fixed = TRUE)) > 0 ||
+      length(grep("~", file, fixed = TRUE)) > 0
+  ) {
     buffer <- read.graph.toraw(file)
     file <- tempfile()
     write.graph.fromraw(buffer, file)
   }
 
   format <- igraph.match.arg(format)
-  res <- switch(format,
+  res <- switch(
+    format,
     "pajek" = read.graph.pajek(file, ...),
     "ncol" = read.graph.ncol(file, ...),
     "edgelist" = read.graph.edgelist(file, ...),
@@ -200,14 +342,12 @@ read_graph <- function(file, format = c(
     "dimacs" = read.graph.dimacs(file, ...),
     "graphdb" = read.graph.graphdb(file, ...),
     "gml" = read.graph.gml(file, ...),
-    "dl" = read.graph.dl(file, ...),
-    stop(paste("Unknown file format:", format))
+    "dl" = read.graph.dl(file, ...)
   )
   res
 }
 
 
-
 #' Writing the graph to a file in some format
 #'
 #' `write_graph()` is a general function for exporting graphs to foreign
@@ -230,15 +370,84 @@ read_graph <- function(file, format = c(
 #' @section NCOL format: This format is a plain text edge list in which vertices
 #' are referred to by name rather than numerical ID. Edge weights may be
 #' optionally written. Additional parameters:
-#' \describe{
-#' \item{names}{The name of a vertex attribute to take vertex names from or
-#' `NULL` to use zero-based numerical IDs.}
-#' \item{weights}{The name of an edge attribute to take edge weights from or
-#' `NULL` to omit edge weights.}
-#' }
+#'   \describe{
+#'     \item{names}{
+#'       The name of a vertex attribute to take vertex names from or
+#'       `NULL` to use zero-based numerical IDs.
+#'     }
+#'     \item{weights}{
+#'       The name of an edge attribute to take edge weights from or
+#'       `NULL` to omit edge weights.
+#'     }
+#'   }
 #' @section Pajek format: The `pajek` format is provided for interoperability
 #' with the Pajek software only. Since the format does not have a formal
 #' specification, it is not recommended for general data exchange or archival.
+#' @section LGL format:
+#' The .lgl format is used by the Large Graph Layout visualization software (<https://lgl.sourceforge.net>), it can describe undirected optionally weighted graphs.
+#' \describe{
+#'   \item{names}{The name of a vertex attribute to use for vertex names, or
+#'     NULL to use numeric IDs.}
+#'   \item{weights}{The name of an edge attribute to use for edge weights, or
+#'     NULL to omit weights.}
+#'   \item{isolates}{Logical, whether to include isolated vertices in the file.
+#'     Default is FALSE.}
+#' }
+#'
+#' @section DIMACS format:
+#' This is a line-oriented text file (ASCII) format.
+#' The first character of each line defines the type of the line.
+#' If the first character is c the line is a comment line and it is ignored.
+#' There is one problem line (p in the file),
+#' it must appear before any node and arc descriptor lines.
+#' The problem line has three fields separated by spaces: the problem type (max or edge),
+#' the number of vertices, and number of edges in the graph. In MAX problems,
+#' exactly two node identification lines are expected (n), one for the source, and one for the target vertex.
+#' These have two fields: the ID of the vertex and the type of the vertex, either s ( = source) or t ( = target).
+#' Arc lines start with a and have three fields: the source vertex, the target vertex and the edge capacity.
+#' In EDGE problems, there may be a node line (n) for each node. It specifies the node index and an
+#'  integer node label. Nodes for which no explicit label was specified will use their index as label.
+#' In EDGE problems, each edge is specified as an edge line (e).
+#' \describe{
+#'   \item{source}{Numeric ID of the source vertex.}
+#'   \item{target}{Numeric ID of the target vertex.}
+#'   \item{capacity}{The name of an edge attribute to use for edge capacities,
+#'     or NULL to use the "capacity" attribute if it exists.}
+#' }
+#'
+#' @section GML format:
+#' GML is a quite general textual format.
+#' \describe{
+#'   \item{id}{Optional numeric vertex IDs to use.}
+#'   \item{creator}{Optional string specifying the creator of the file.}
+#' }
+#'
+#' @section GraphML format:
+#' GraphML is an XML-based file format for representing various types of graphs.
+#' When a numerical attribute value is NaN, it will be omitted from the file.
+#' This function assumes that non-ASCII characters in attribute names and string
+#' attribute values are UTF-8 encoded. If this is not the case, the resulting XML file will be invalid. Control characters, i.e. character codes up to and including 31 (with the exception of tab, cr and lf), are not allowed.
+#' \describe{
+#'   \item{prefixAttr}{Logical, whether to prefix attribute names to ensure
+#'     uniqueness across vertex/edge/graph attributes. Default is TRUE.}
+#' }
+#'
+#' @section LEDA format:
+#' This function writes a graph to an output stream in LEDA format.
+#' See <https://www.algorithmic-solutions.info/leda_guide/graphs/leda_native_graph_fileformat.html>.
+#' The support for the LEDA format is very basic at the moment; igraph writes only the LEDA graph section which supports one selected vertex and edge
+#' attribute and no layout information or visual attributes.
+#' \describe{
+#'   \item{vertex.attr}{Name of vertex attribute to include in the file.}
+#'   \item{edge.attr}{Name of edge attribute to include in the file.}
+#' }
+#' @section DOT format:
+#' DOT is the format used by the widely known GraphViz software, see <https://www.graphviz.org> for details.
+#' The grammar of the DOT format can be found here: <https://www.graphviz.org/doc/info/lang.html>.
+#' This is only a preliminary implementation, no visualization information is written.
+#' This format is meant solely for interoperability with Graphviz. It is not recommended for
+#' data exchange or archival.
+#'
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @seealso [read_graph()]
 #' @references Adai AT, Date SV, Wieland S, Marcotte EM. LGL: creating a map of
@@ -259,15 +468,28 @@ read_graph <- function(file, format = c(
 #'   unlink(file)
 #' }
 #'
-write_graph <- function(graph, file,
-                        format = c(
-                          "edgelist", "pajek", "ncol", "lgl",
-                          "graphml", "dimacs", "gml", "dot", "leda"
-                        ),
-                        ...) {
+write_graph <- function(
+  graph,
+  file,
+  format = c(
+    "edgelist",
+    "pajek",
+    "ncol",
+    "lgl",
+    "graphml",
+    "dimacs",
+    "gml",
+    "dot",
+    "leda"
+  ),
+  ...
+) {
   ensure_igraph(graph)
-  if (!is.character(file) || length(grep("://", file, fixed = TRUE)) > 0 ||
-    length(grep("~", file, fixed = TRUE)) > 0) {
+  if (
+    !is.character(file) ||
+      length(grep("://", file, fixed = TRUE)) > 0 ||
+      length(grep("~", file, fixed = TRUE)) > 0
+  ) {
     tmpfile <- TRUE
     origfile <- file
     file <- tempfile()
@@ -276,7 +498,8 @@ write_graph <- function(graph, file,
   }
 
   format <- igraph.match.arg(format)
-  res <- switch(format,
+  res <- switch(
+    format,
     "pajek" = write.graph.pajek(graph, file, ...),
     "edgelist" = write.graph.edgelist(graph, file, ...),
     "ncol" = write.graph.ncol(graph, file, ...),
@@ -285,8 +508,7 @@ write_graph <- function(graph, file,
     "dimacs" = write.graph.dimacs(graph, file, ...),
     "gml" = write.graph.gml(graph, file, ...),
     "dot" = write.graph.dot(graph, file, ...),
-    "leda" = write.graph.leda(graph, file, ...),
-    stop(paste("Unknown file format:", format))
+    "leda" = write.graph.leda(graph, file, ...)
   )
 
   if (tmpfile) {
@@ -301,22 +523,17 @@ write_graph <- function(graph, file,
 # Plain edge list format, not sorted
 ################################################################
 
-read.graph.edgelist <- function(file, n = 0,
-                                directed = TRUE, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to read_graph (edgelist format)")
-  }
+read.graph.edgelist <- function(file, n = 0, directed = TRUE) {
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_read_graph_edgelist, file,
-    as.numeric(n), as.logical(directed)
+    R_igraph_read_graph_edgelist,
+    file,
+    as.numeric(n),
+    as.logical(directed)
   )
 }
 
-write.graph.edgelist <- function(graph, file, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to write_graph (edgelist format)")
-  }
+write.graph.edgelist <- function(graph, file) {
   on.exit(.Call(R_igraph_finalizer))
   .Call(R_igraph_write_graph_edgelist, graph, file)
 }
@@ -325,29 +542,36 @@ write.graph.edgelist <- function(graph, file, ...) {
 # NCOL and LGL formats, quite simple
 ################################################################
 
-read.graph.ncol <- function(file, predef = character(0), names = TRUE,
-                            weights = c("auto", "yes", "no"),
-                            directed = FALSE, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to read_graph (NCOL format)")
-  }
-  weights <- switch(igraph.match.arg(weights),
+read.graph.ncol <- function(
+  file,
+  predef = character(0),
+  names = TRUE,
+  weights = c("auto", "yes", "no"),
+  directed = FALSE
+) {
+  weights <- switch(
+    igraph.match.arg(weights),
     "no" = 0L,
     "yes" = 1L,
     "auto" = 2L
   )
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_read_graph_ncol, file, as.character(predef),
-    as.logical(names), weights, as.logical(directed)
+    R_igraph_read_graph_ncol,
+    file,
+    as.character(predef),
+    as.logical(names),
+    weights,
+    as.logical(directed)
   )
 }
 
-write.graph.ncol <- function(graph, file,
-                             names = "name", weights = "weight", ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to write_graph (NCOL format)")
-  }
+write.graph.ncol <- function(
+  graph,
+  file,
+  names = "name",
+  weights = "weight"
+) {
   names <- as.character(names)
   weights <- as.character(weights)
   if (length(names) == 0 || !names %in% vertex_attr_names(graph)) {
@@ -359,36 +583,43 @@ write.graph.ncol <- function(graph, file,
 
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_write_graph_ncol, graph, file,
-    names, weights
+    R_igraph_write_graph_ncol,
+    graph,
+    file,
+    names,
+    weights
   )
 }
 
-read.graph.lgl <- function(file, names = TRUE,
-                           weights = c("auto", "yes", "no"),
-                           directed = FALSE,
-                           ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to read_graph (LGL format)")
-  }
-  weights <- switch(igraph.match.arg(weights),
+read.graph.lgl <- function(
+  file,
+  names = TRUE,
+  weights = c("auto", "yes", "no"),
+  directed = FALSE
+) {
+  weights <- switch(
+    igraph.match.arg(weights),
     "no" = 0L,
     "yes" = 1L,
     "auto" = 2L
   )
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_read_graph_lgl, file,
-    as.logical(names), weights, as.logical(directed)
+    R_igraph_read_graph_lgl,
+    file,
+    as.logical(names),
+    weights,
+    as.logical(directed)
   )
 }
 
-write.graph.lgl <- function(graph, file,
-                            names = "name", weights = "weight",
-                            isolates = FALSE, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to write_graph (LGL format)")
-  }
+write.graph.lgl <- function(
+  graph,
+  file,
+  names = "name",
+  weights = "weight",
+  isolates = FALSE
+) {
   names <- as.character(names)
   weights <- as.character(weights)
   if (length(names) == 0 || !names %in% vertex_attr_names(graph)) {
@@ -400,15 +631,16 @@ write.graph.lgl <- function(graph, file,
 
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_write_graph_lgl, graph, file,
-    names, weights, as.logical(isolates)
+    R_igraph_write_graph_lgl,
+    graph,
+    file,
+    names,
+    weights,
+    as.logical(isolates)
   )
 }
 
-read.graph.pajek <- function(file, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to read_graph (Pajek format)")
-  }
+read.graph.pajek <- function(file) {
   on.exit(.Call(R_igraph_finalizer))
   res <- .Call(R_igraph_read_graph_pajek, file)
   if ("type" %in% vertex_attr_names(res)) {
@@ -419,18 +651,12 @@ read.graph.pajek <- function(file, ...) {
   res
 }
 
-write.graph.pajek <- function(graph, file, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to write_graph (Pajek format)")
-  }
+write.graph.pajek <- function(graph, file) {
   on.exit(.Call(R_igraph_finalizer))
   .Call(R_igraph_write_graph_pajek, graph, file)
 }
 
-read.graph.dimacs <- function(file, directed = TRUE, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to read_graph (DIMACS format)")
-  }
+read.graph.dimacs <- function(file, directed = TRUE) {
   res <- .Call(R_igraph_read_graph_dimacs, file, as.logical(directed))
   if (res[[1]][1] == "max") {
     graph <- res[[2]]
@@ -447,11 +673,13 @@ read.graph.dimacs <- function(file, directed = TRUE, ...) {
   }
 }
 
-write.graph.dimacs <- function(graph, file,
-                               source = NULL, target = NULL, capacity = NULL, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to write_graph (DIMACS format)")
-  }
+write.graph.dimacs <- function(
+  graph,
+  file,
+  source = NULL,
+  target = NULL,
+  capacity = NULL
+) {
   if (is.null(source)) {
     source <- graph_attr(graph, "source")
   }
@@ -464,8 +692,12 @@ write.graph.dimacs <- function(graph, file,
 
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_write_graph_dimacs, graph, file, as.numeric(source),
-    as.numeric(target), as.numeric(capacity)
+    R_igraph_write_graph_dimacs,
+    graph,
+    file,
+    as.numeric(source),
+    as.numeric(target),
+    as.numeric(capacity)
   )
 }
 
@@ -473,18 +705,12 @@ write.graph.dimacs <- function(graph, file,
 # GraphML
 ################################################################
 
-read.graph.graphml <- function(file, index = 0, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to read_graph (GraphML format)")
-  }
+read.graph.graphml <- function(file, index = 0) {
   on.exit(.Call(R_igraph_finalizer))
   .Call(R_igraph_read_graph_graphml, file, as.numeric(index))
 }
 
-write.graph.graphml <- function(graph, file, prefixAttr = TRUE, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to write_graph (GraphML format)")
-  }
+write.graph.graphml <- function(graph, file, prefixAttr = TRUE) {
   on.exit(.Call(R_igraph_finalizer))
   .Call(R_igraph_write_graph_graphml, graph, file, as.logical(prefixAttr))
 }
@@ -493,18 +719,12 @@ write.graph.graphml <- function(graph, file, prefixAttr = TRUE, ...) {
 # GML
 ################################################################
 
-read.graph.gml <- function(file, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to read_graph (GML format)")
-  }
+read.graph.gml <- function(file) {
   on.exit(.Call(R_igraph_finalizer))
   .Call(R_igraph_read_graph_gml, file)
 }
 
-write.graph.gml <- function(graph, file, id = NULL, creator = NULL, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to write_graph (GML format)")
-  }
+write.graph.gml <- function(graph, file, id = NULL, creator = NULL) {
   if (!is.null(id)) {
     id <- as.numeric(id)
   }
@@ -519,10 +739,7 @@ write.graph.gml <- function(graph, file, id = NULL, creator = NULL, ...) {
 # UCINET DL
 ################################################################
 
-read.graph.dl <- function(file, directed = TRUE, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to read_graph (DL format)")
-  }
+read.graph.dl <- function(file, directed = TRUE) {
   on.exit(.Call(R_igraph_finalizer))
   .Call(R_igraph_read_graph_dl, file, as.logical(directed))
 }
@@ -531,10 +748,7 @@ read.graph.dl <- function(file, directed = TRUE, ...) {
 # Dot
 ################################################################
 
-write.graph.dot <- function(graph, file, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to write_graph (DOT format)")
-  }
+write.graph.dot <- function(graph, file) {
   on.exit(.Call(R_igraph_finalizer))
   .Call(R_igraph_write_graph_dot, graph, file)
 }
@@ -544,12 +758,10 @@ write.graph.dot <- function(graph, file, ...) {
 # isomorphic problems
 ################################################################
 
-
-
 #' Load a graph from the graph database for testing graph isomorphism.
 #'
 #' This function downloads a graph from a database created for the evaluation
-#' of graph isomorphism testing algothitms.
+#' of graph isomorphism testing algorithms.
 #'
 #' `graph_from_graphdb()` reads a graph from the graph database from an FTP or
 #' HTTP server or from a local copy. It has two modes of operation:
@@ -564,7 +776,7 @@ write.graph.dot <- function(graph, file, ...) {
 #'
 #' Unfortunately the original graph database homepage is now defunct, but see
 #' its old version at
-#' <http://web.archive.org/web/20090215182331/http://amalfi.dis.unina.it/graph/db/doc/graphdbat.html>
+#' <https://web.archive.org/web/20090215182331/http://amalfi.dis.unina.it/graph/db/doc/graphdbat.html>
 #' for the actual format of a graph database file and other information.
 #'
 #' @param url If not `NULL` it is a complete URL with the file to import.
@@ -597,42 +809,93 @@ write.graph.dot <- function(graph, file, ...) {
 #' @family foreign
 #' @export
 #' @keywords graphs
-graph_from_graphdb <- function(url = NULL,
-                               prefix = "iso", type = "r001", nodes = NULL, pair = "A", which = 0,
-                               base = "http://cneurocvs.rmki.kfki.hu/graphdb/gzip",
-                               compressed = TRUE, directed = TRUE) {
+graph_from_graphdb <- function(
+  url = NULL,
+  prefix = "iso",
+  type = "r001",
+  nodes = NULL,
+  pair = "A",
+  which = 0,
+  base = "https://github.com/igraph/graphsdb/raw/refs/heads/main",
+  compressed = TRUE,
+  directed = TRUE
+) {
   if (is.null(nodes) && is.null(url)) {
-    stop("The `nodes' or the `url' argument must be non-null")
+    cli::cli_abort("Either {.arg nodes}' or `{.arg url}' must be non-null.")
   }
 
   if (is.null(url)) {
     prefixes <- c("iso", "si6", "mcs10", "mcs30", "mcs50", "mcs70", "mcs90")
     types <- c(
-      "r001", "r005", "r01", "r02", "m2D", "m2Dr2", "m2Dr4", "m2Dr6",
-      "m3D", "m3Dr2", "m3Dr4", "m3Dr6", "m4D", "m4Dr2", "m4Dr4",
-      "m4Dr6", "b03", "b03m", "b06", "b06m", "b09", "b09m"
+      "r001",
+      "r005",
+      "r01",
+      "r02",
+      "m2D",
+      "m2Dr2",
+      "m2Dr4",
+      "m2Dr6",
+      "m3D",
+      "m3Dr2",
+      "m3Dr4",
+      "m3Dr6",
+      "m4D",
+      "m4Dr2",
+      "m4Dr4",
+      "m4Dr6",
+      "b03",
+      "b03m",
+      "b06",
+      "b06m",
+      "b09",
+      "b09m"
     )
-    sizecode <- if (nodes <= 100) "s" else if (nodes < 2000) "m" else "l" # "l" ????
-    typegroups <- c(
-      "rand", "rand", "rand", "rand",
-      "m2D", "m2D", "m2D", "m2D",
-      "m2D", "m3D", "m3D", "m3D",
-      "m4D", "m4D", "m4D", "m4D",
-      "bvg", "bvg", "bvg", "bvg", "bvg", "bvg"
+    sizecode <- if (nodes <= 100) {
+      "s"
+    } else if (nodes < 2000) {
+      "m"
+    } else {
+      "l"
+    } # "l" ????
+    typegroups <- rep(
+      c("rand", "m2D", "m3D", "m4D", "bvg"),
+      c(4L, 5L, 3L, 4L, 6L)
     )
     typegroup <- typegroups[which(types == type)]
 
     if (!prefix %in% prefixes) {
-      stop("Invalid prefix!")
+      cli::cli_abort(c(
+        "{.value {prefix}} is not a valid prefix.",
+        i = "Must be one of {.value {prefixes}}."
+      ))
     }
     if (!type %in% types) {
-      stop("Invalid graph type!")
+      cli::cli_abort(c(
+        "{.value {type}} is not a valid graph type.",
+        i = "Must be one of {.value {types}}."
+      ))
     }
     suff <- if (compressed) ".gz" else ""
     filename <- paste(
-      sep = "", base, "/", prefix, "/", typegroup, "/", type, "/",
-      prefix, "_", type, "_", sizecode, nodes,
-      ".", pair, formatC(which, width = 2, flag = "0"), suff
+      sep = "",
+      base,
+      "/",
+      prefix,
+      "/",
+      typegroup,
+      "/",
+      type,
+      "/",
+      prefix,
+      "_",
+      type,
+      "_",
+      sizecode,
+      nodes,
+      ".",
+      pair,
+      formatC(which, width = 2, flag = "0"),
+      suff
     )
   } else {
     filename <- url
@@ -642,7 +905,9 @@ graph_from_graphdb <- function(url = NULL,
 
   f <- try(gzcon(file(filename, open = "rb")))
   if (inherits(f, "try-error")) {
-    stop(paste("Cannot open URL:", filename))
+    cli::cli_abort(
+      "Cannot open URL provided in {.arg filename}: {.url {filename}}"
+    )
   }
 
   buffer <- read.graph.toraw(f)
@@ -652,19 +917,17 @@ graph_from_graphdb <- function(url = NULL,
   .Call(R_igraph_read_graph_graphdb, f, as.logical(directed))
 }
 
-read.graph.graphdb <- function(file, directed = TRUE, ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to read_graph (GraphDB format)")
-  }
+read.graph.graphdb <- function(file, directed = TRUE) {
   on.exit(.Call(R_igraph_finalizer))
   .Call(R_igraph_read_graph_graphdb, file, as.logical(directed))
 }
 
-write.graph.leda <- function(graph, file, vertex.attr = NULL, edge.attr = NULL,
-                             ...) {
-  if (length(list(...)) > 0) {
-    stop("Unknown arguments to write_graph (LEDA format)")
-  }
+write.graph.leda <- function(
+  graph,
+  file,
+  vertex.attr = NULL,
+  edge.attr = NULL
+) {
   if (!is.null(vertex.attr)) {
     vertex.attr <- as.character(vertex.attr)
   }
