@@ -1,17 +1,29 @@
-
 #' Predict edges based on a hierarchical random graph model
 #'
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `hrg.predict()` was renamed to `predict_edges()` to create a more
+#' `hrg.predict()` was renamed to [predict_edges()] to create a more
 #' consistent API.
 #' @inheritParams predict_edges
 #' @keywords internal
 #' @export
-hrg.predict <- function(graph, hrg = NULL, start = FALSE, num.samples = 10000, num.bins = 25) { # nocov start
+hrg.predict <- function(
+  graph,
+  hrg = NULL,
+  start = FALSE,
+  num.samples = 10000,
+  num.bins = 25
+) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "hrg.predict()", "predict_edges()")
-  predict_edges(graph = graph, hrg = hrg, start = start, num.samples = num.samples, num.bins = num.bins)
+  predict_edges(
+    graph = graph,
+    hrg = hrg,
+    start = start,
+    num.samples = num.samples,
+    num.bins = num.bins
+  )
 } # nocov end
 
 #' Fit a hierarchical random graph model
@@ -19,12 +31,13 @@ hrg.predict <- function(graph, hrg = NULL, start = FALSE, num.samples = 10000, n
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `hrg.fit()` was renamed to `fit_hrg()` to create a more
+#' `hrg.fit()` was renamed to [fit_hrg()] to create a more
 #' consistent API.
 #' @inheritParams fit_hrg
 #' @keywords internal
 #' @export
-hrg.fit <- function(graph, hrg = NULL, start = FALSE, steps = 0) { # nocov start
+hrg.fit <- function(graph, hrg = NULL, start = FALSE, steps = 0) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "hrg.fit()", "fit_hrg()")
   fit_hrg(graph = graph, hrg = hrg, start = start, steps = steps)
 } # nocov end
@@ -34,12 +47,13 @@ hrg.fit <- function(graph, hrg = NULL, start = FALSE, steps = 0) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `hrg.game()` was renamed to `sample_hrg()` to create a more
+#' `hrg.game()` was renamed to [sample_hrg()] to create a more
 #' consistent API.
 #' @inheritParams sample_hrg
 #' @keywords internal
 #' @export
-hrg.game <- function(hrg) { # nocov start
+hrg.game <- function(hrg) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "hrg.game()", "sample_hrg()")
   sample_hrg(hrg = hrg)
 } # nocov end
@@ -49,12 +63,13 @@ hrg.game <- function(hrg) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `hrg.dendrogram()` was renamed to `hrg_tree()` to create a more
+#' `hrg.dendrogram()` was renamed to [hrg_tree()] to create a more
 #' consistent API.
 #' @inheritParams hrg_tree
 #' @keywords internal
 #' @export
-hrg.dendrogram <- function(hrg) { # nocov start
+hrg.dendrogram <- function(hrg) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "hrg.dendrogram()", "hrg_tree()")
   hrg_tree(hrg = hrg)
 } # nocov end
@@ -64,12 +79,13 @@ hrg.dendrogram <- function(hrg) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `hrg.create()` was renamed to `hrg()` to create a more
+#' `hrg.create()` was renamed to [hrg()] to create a more
 #' consistent API.
 #' @inheritParams hrg
 #' @keywords internal
 #' @export
-hrg.create <- function(graph, prob) { # nocov start
+hrg.create <- function(graph, prob) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "hrg.create()", "hrg()")
   hrg(graph = graph, prob = prob)
 } # nocov end
@@ -79,14 +95,25 @@ hrg.create <- function(graph, prob) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `hrg.consensus()` was renamed to `consensus_tree()` to create a more
+#' `hrg.consensus()` was renamed to [consensus_tree()] to create a more
 #' consistent API.
 #' @inheritParams consensus_tree
 #' @keywords internal
 #' @export
-hrg.consensus <- function(graph, hrg = NULL, start = FALSE, num.samples = 10000) { # nocov start
+hrg.consensus <- function(
+  graph,
+  hrg = NULL,
+  start = FALSE,
+  num.samples = 10000
+) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "hrg.consensus()", "consensus_tree()")
-  consensus_tree(graph = graph, hrg = hrg, start = start, num.samples = num.samples)
+  consensus_tree(
+    graph = graph,
+    hrg = hrg,
+    start = start,
+    num.samples = num.samples
+  )
 } # nocov end
 #   IGraph R package
 #   Copyright (C) 2011-2012  Gabor Csardi <csardi.gabor@gmail.com>
@@ -156,21 +183,31 @@ NULL
 #'   MCMC procedure is performed until convergence.
 #' @return `fit_hrg()` returns an `igraphHRG` object. This is a list
 #'   with the following members:
-#'   \item{left}{Vector that contains the left children of the internal
-#'     tree vertices. The first vertex is always the root vertex, so the
-#'     first element of the vector is the left child of the root
-#'     vertex. Internal vertices are denoted with negative numbers, starting
-#'     from -1 and going down, i.e. the root vertex is -1. Leaf vertices
-#'     are denoted by non-negative number, starting from zero and up.}
-#'   \item{right}{Vector that contains the right children of the vertices,
-#'     with the same encoding as the `left` vector.}
-#'   \item{prob}{The connection probabilities attached to the internal
-#'     vertices, the first number belongs to the root vertex (i.e. internal
-#'     vertex -1), the second to internal vertex -2, etc.}
-#'   \item{edges}{The number of edges in the subtree below the given
-#'     internal vertex.}
-#'   \item{vertices}{The number of vertices in the subtree below the
-#'     given internal vertex, including itself.}
+#'   \describe{
+#'     \item{left}{
+#'       Vector that contains the left children of the internal tree vertices.
+#'       The first vertex is always the root vertex,
+#'       so the first element of the vector is the left child of the root vertex.
+#'       Internal vertices are denoted with negative numbers,
+#'       starting from -1 and going down, i.e. the root vertex is -1.
+#'       Leaf vertices are denoted by non-negative number, starting from zero and up.
+#'     }
+#'     \item{right}{
+#'       Vector that contains the right children of the vertices,
+#'       with the same encoding as the `left` vector.
+#'     }
+#'     \item{prob}{
+#'       The connection probabilities attached to the internal vertices,
+#'       the first number belongs to the root vertex (i.e. internal vertex -1),
+#'       the second to internal vertex -2, etc.
+#'     }
+#'     \item{edges}{
+#'       The number of edges in the subtree below the given internal vertex.
+#'     }
+#'     \item{vertices}{
+#'       The number of vertices in the subtree below the given internal vertex, including itself.
+#'     }
+#'   }
 #' @references A. Clauset, C. Moore, and M.E.J. Newman. Hierarchical structure
 #' and the prediction of missing links in networks. *Nature* 453, 98--101
 #' (2008);
@@ -200,7 +237,10 @@ fit_hrg <- function(graph, hrg = NULL, start = FALSE, steps = 0) {
   ensure_igraph(graph)
   if (is.null(hrg)) {
     hrg <- list(
-      left = c(), right = c(), prob = c(), edges = c(),
+      left = c(),
+      right = c(),
+      prob = c(),
+      edges = c(),
       vertices = c()
     )
   }
@@ -245,13 +285,19 @@ fit_hrg <- function(graph, hrg = NULL, start = FALSE, steps = 0) {
 #'   is an `igraphHRGConsensus` object, the second is an
 #'   `igraphHRG` object.  The `igraphHRGConsensus` object has the
 #'   following members:
-#'   \item{parents}{For each vertex, the id of its parent vertex is stored,
-#'     or zero, if the vertex is the root vertex in the tree. The first n
-#'     vertex ids (from 0) refer to the original vertices of the graph, the
-#'     other ids refer to vertex groups.}
-#'   \item{weights}{Numeric vector, counts the number of times a given tree
-#'     split occurred in the generated network samples, for each internal
-#'     vertices. The order is the same as in the `parents` vector.}
+#'   \describe{
+#'     \item{parents}{
+#'       For each vertex, the id of its parent vertex is stored,
+#'       or zero, if the vertex is the root vertex in the tree.
+#'       The first n vertex ids (from 0) refer to the original vertices of the graph,
+#'       the other ids refer to vertex groups.
+#'     }
+#'     \item{weights}{
+#'       Numeric vector, counts the number of times a given tree split
+#'       occurred in the generated network samples, for each internal vertices.
+#'       The order is the same as in the `parents` vector.
+#'     }
+#'   }
 #' @family hierarchical random graph functions
 #' @export
 #' @cdocs igraph_hrg_consensus
@@ -288,6 +334,12 @@ hrg <- hrg_create_impl
 #' @export
 #' @cdocs igraph_from_hrg_dendrogram
 hrg_tree <- function(hrg) {
+  if (!inherits(hrg, "igraphHRG")) {
+    cli::cli_abort(
+      "{.arg hrg} must be an {.cls igraphHRG} object, not {.obj_type_friendly {hrg}}."
+    )
+  }
+
   out <- from_hrg_dendrogram_impl(hrg)
 
   g <- out$graph
@@ -306,8 +358,15 @@ hrg_tree <- function(hrg) {
 #' @family hierarchical random graph functions
 #' @export
 #' @cdocs igraph_hrg_game
-sample_hrg <- hrg_game_impl
+sample_hrg <- function(hrg) {
+  if (!inherits(hrg, "igraphHRG")) {
+    cli::cli_abort(
+      "{.arg hrg} must be an {.cls igraphHRG} object, not {.obj_type_friendly {hrg}}."
+    )
+  }
 
+  hrg_game_impl(hrg)
+}
 #' Predict edges based on a hierarchical random graph model
 #'
 #' `predict_edges()` uses a hierarchical random graph model to predict
@@ -330,11 +389,17 @@ sample_hrg <- hrg_game_impl
 #' @param num.bins Number of bins for the edge probabilities. Give a higher
 #'   number for a more accurate prediction.
 #' @return A list with entries:
-#'   \item{edges}{The predicted edges, in a two-column matrix of vertex
-#'     ids.}
-#'   \item{prob}{Probabilities of these edges, according to the fitted
-#'     model.}
-#'   \item{hrg}{The (supplied or fitted) hierarchical random graph model.}
+#'   \describe{
+#'     \item{edges}{
+#'       The predicted edges, in a two-column matrix of vertex ids.
+#'     }
+#'     \item{prob}{
+#'       Probabilities of these edges, according to the fitted model.
+#'     }
+#'     \item{hrg}{
+#'       The (supplied or fitted) hierarchical random graph model.
+#'     }
+#'   }
 #'
 #' @references A. Clauset, C. Moore, and M.E.J. Newman. Hierarchical structure
 #' and the prediction of missing links in networks. *Nature* 453, 98--101
@@ -359,13 +424,21 @@ sample_hrg <- hrg_game_impl
 #' predict_edges(g2)
 #' @export
 #' @family hierarchical random graph functions
-predict_edges <- function(graph, hrg = NULL, start = FALSE, num.samples = 10000,
-                          num.bins = 25) {
+predict_edges <- function(
+  graph,
+  hrg = NULL,
+  start = FALSE,
+  num.samples = 10000,
+  num.bins = 25
+) {
   # Argument checks
   ensure_igraph(graph)
   if (is.null(hrg)) {
     hrg <- list(
-      left = c(), right = c(), prob = c(), edges = c(),
+      left = c(),
+      right = c(),
+      prob = c(),
+      edges = c(),
       vertices = c()
     )
   }
@@ -380,7 +453,11 @@ predict_edges <- function(graph, hrg = NULL, start = FALSE, num.samples = 10000,
   on.exit(.Call(R_igraph_finalizer))
   # Function call
   res <- .Call(
-    R_igraph_hrg_predict, graph, hrg, start, num.samples,
+    R_igraph_hrg_predict,
+    graph,
+    hrg,
+    start,
+    num.samples,
     num.bins
   )
   res$edges <- matrix(res$edges, ncol = 2, byrow = TRUE)
@@ -389,7 +466,6 @@ predict_edges <- function(graph, hrg = NULL, start = FALSE, num.samples = 10000,
 }
 
 
-
 #' Conversion to igraph
 #'
 #' These functions convert various objects to igraph graphs.
@@ -449,9 +525,11 @@ buildMerges <- function(object) {
   while (length(S) != 0) {
     curr <- S[length(S)]
     ## coming from parent? going left if possible.
-    if (is.null(prev) ||
-      (prev < 0 && object$left[-prev] == curr) ||
-      (prev < 0 && object$right[-prev] == curr)) {
+    if (
+      is.null(prev) ||
+        (prev < 0 && object$left[-prev] == curr) ||
+        (prev < 0 && object$right[-prev] == curr)
+    ) {
       if (curr < 0) {
         S <- c(S, object$left[-curr])
       }
@@ -495,7 +573,8 @@ as.dendrogram.igraphHRG <- function(object, hang = 0.01, ...) {
     if (any(neg <- x >= 0)) {
       h0 <- if (hang < 0) 0 else max(0, oHgt[k] - hang * hMax)
     }
-    if (all(neg)) { # two leaves
+    if (all(neg)) {
+      # two leaves
       zk <- as.list(x + 1)
       attr(zk, "members") <- 2L
       attr(zk, "midpoint") <- 1 / 2 # mean( c(0,1) )
@@ -505,7 +584,8 @@ as.dendrogram.igraphHRG <- function(object, hang = 0.01, ...) {
       attr(zk[[1]], "members") <- attr(zk[[2]], "members") <- 1L
       attr(zk[[1]], "height") <- attr(zk[[2]], "height") <- h0
       attr(zk[[1]], "leaf") <- attr(zk[[2]], "leaf") <- TRUE
-    } else if (any(neg)) { # one leaf, one node
+    } else if (any(neg)) {
+      # one leaf, one node
       X <- paste0("g", -x)
       isL <- x[1] >= 0
       zk <- if (isL) list(x[1] + 1, z[[X[2]]]) else list(z[[X[1]]], x[2] + 1)
@@ -516,14 +596,16 @@ as.dendrogram.igraphHRG <- function(object, hang = 0.01, ...) {
       attr(zk[[2 - isL]], "height") <- h0
       attr(zk[[2 - isL]], "label") <- mynames[x[2 - isL] + 1]
       attr(zk[[2 - isL]], "leaf") <- TRUE
-    } else { # two nodes
+    } else {
+      # two nodes
       X <- paste0("g", -x)
       zk <- list(z[[X[1]]], z[[X[2]]])
       attr(zk, "members") <- attr(z[[X[1]]], "members") +
         attr(z[[X[2]]], "members")
       attr(zk, "midpoint") <- (attr(z[[X[1]]], "members") +
         attr(z[[X[1]]], "midpoint") +
-        attr(z[[X[2]]], "midpoint")) / 2
+        attr(z[[X[2]]], "midpoint")) /
+        2
     }
     attr(zk, "height") <- oHgt[k]
     z[[k <- paste0("g", -merges[k, 3])]] <- zk
@@ -568,8 +650,11 @@ as.hclust.igraphHRG <- function(x, ...) {
 
   mynames <- if (is.null(x$names)) 1:n else x$names
   res <- list(
-    merge = merge, height = 1:nrow(merge), order = order,
-    labels = mynames, method = NA_character_,
+    merge = merge,
+    height = 1:nrow(merge),
+    order = order,
+    labels = mynames,
+    method = NA_character_,
     dist.method = NA_character_
   )
   class(res) <- "hclust"
@@ -589,7 +674,9 @@ as.phylo.igraphHRG <- function(x, ...) {
   edge.length <- rep(0.5, nrow(edge))
   labels <- if (is.null(x$names)) 1:ovc else x$names
   obj <- list(
-    edge = edge, edge.length = edge.length / 2, tip.label = labels,
+    edge = edge,
+    edge.length = edge.length / 2,
+    tip.label = labels,
     Nnode = ivc
   )
   class(obj) <- "phylo"
@@ -673,7 +760,11 @@ rlang::on_load(s3_register("ape::as.phylo", "igraphHRG"))
 #' hrg <- fit_hrg(g)
 #' plot_dendrogram(hrg)
 #'
-plot_dendrogram.igraphHRG <- function(x, mode = igraph_opt("dend.plot.type"), ...) {
+plot_dendrogram.igraphHRG <- function(
+  x,
+  mode = igraph_opt("dend.plot.type"),
+  ...
+) {
   if (mode == "auto") {
     have_ape <- requireNamespace("ape", quietly = TRUE)
     mode <- if (have_ape) "phylo" else "hclust"
@@ -691,13 +782,28 @@ plot_dendrogram.igraphHRG <- function(x, mode = igraph_opt("dend.plot.type"), ..
 #' @importFrom graphics plot
 #' @importFrom grDevices rainbow
 #' @importFrom stats rect.hclust
-hrgPlotHclust <- function(x, rect = 0, colbar = rainbow(rect), hang = .01,
-                          ann = FALSE, main = "", sub = "", xlab = "", ylab = "",
-                          ...) {
+hrgPlotHclust <- function(
+  x,
+  rect = 0,
+  colbar = rainbow(rect),
+  hang = .01,
+  ann = FALSE,
+  main = "",
+  sub = "",
+  xlab = "",
+  ylab = "",
+  ...
+) {
   hc <- as.hclust(x)
-  ret <- plot(hc,
-    hang = hang, ann = ann, main = main, sub = sub, xlab = xlab,
-    ylab = ylab, ...
+  ret <- plot(
+    hc,
+    hang = hang,
+    ann = ann,
+    main = main,
+    sub = sub,
+    xlab = xlab,
+    ylab = ylab,
+    ...
   )
   if (rect > 0) {
     rect.hclust(hc, k = rect, border = colbar)
@@ -712,8 +818,13 @@ hrgPlotDendrogram <- function(x, ...) {
 
 #' @importFrom graphics plot
 #' @importFrom grDevices rainbow
-hrgPlotPhylo <- function(x, colbar = rainbow(11, start = .7, end = .1),
-                         edge.color = NULL, use.edge.length = FALSE, ...) {
+hrgPlotPhylo <- function(
+  x,
+  colbar = rainbow(11, start = .7, end = .1),
+  edge.color = NULL,
+  use.edge.length = FALSE,
+  ...
+) {
   vc <- length(x$left) + 1
   phy <- ape::as.phylo(x)
   br <- seq(0, 1, length.out = length(colbar))
@@ -769,11 +880,16 @@ hrgPlotPhylo <- function(x, colbar = rainbow(11, start = .7, end = .1),
 #' @method print igraphHRG
 #' @export
 #' @family hierarchical random graph functions
-print.igraphHRG <- function(x, type = c("auto", "tree", "plain"),
-                            level = 3, ...) {
+print.igraphHRG <- function(
+  x,
+  type = c("auto", "tree", "plain"),
+  level = 3,
+  ...
+) {
   type <- igraph.match.arg(type)
   if (type == "auto") {
-    type <- if (length(x$left <= 100)) "tree" else "plain"
+    is_graph_small <- (length(x$left) <= 100)
+    type <- if (is_graph_small) "tree" else "plain"
   }
   if (type == "tree") {
     return(print1.igraphHRG(x, level = level, ...))
@@ -876,19 +992,26 @@ print1.igraphHRG <- function(x, level = 3, ...) {
       lf <- paste(collapse = "\n", lf)
     }
     op <- paste(
-      sep = "", format(he, width = cs),
-      " p=", format(x$prob[b], digits = 2, width = pw, justify = "left"),
-      "  ", paste(collapse = " ", lf)
+      sep = "",
+      format(he, width = cs),
+      " p=",
+      format(x$prob[b], digits = 2, width = pw, justify = "left"),
+      "  ",
+      paste(collapse = " ", lf)
     )
     cat(op, fill = TRUE)
 
     ## recursive call
-    if (x$left[b] < 0 && l < level) .plot(-x$left[b], l + 1, ind)
+    if (x$left[b] < 0 && l < level) {
+      .plot(-x$left[b], l + 1, ind)
+    }
     if (x$right[b] < 0 && l < level) .plot(-x$right[b], l + 1, ind)
   }
 
   ## Do it
-  if (length(x$left) > 0) .plot(b = 1, l = 1)
+  if (length(x$left) > 0) {
+    .plot(b = 1, l = 1)
+  }
 
   invisible(x)
 }
@@ -911,9 +1034,13 @@ print2.igraphHRG <- function(x, ...) {
       nn[x$right[i] + 1]
     }
     paste(
-      sep = "", format(paste(sep = "", "g", i), width = bw),
+      sep = "",
+      format(paste(sep = "", "g", i), width = bw),
       format(paste(sep = "", " p=", p[i]), width = pw),
-      "-> ", lc, " ", rc
+      "-> ",
+      lc,
+      " ",
+      rc
     )
   })
   op <- format(op, justify = "left")
@@ -955,9 +1082,11 @@ print.igraphHRGConsensus <- function(x, ...) {
       mych <- gsub(" ", "x", mych, fixed = TRUE)
       mych <- paste(collapse = " ", mych)
       pref <- paste(collapse = "", rep(" ", bw + 5))
-      mych <- strwrap(mych,
+      mych <- strwrap(
+        mych,
         width = getOption("width") - bw - 4,
-        initial = "", prefix = pref
+        initial = "",
+        prefix = pref
       )
       mych <- gsub("x", " ", mych, fixed = TRUE)
       mych <- paste(collapse = "\n", mych)
@@ -1015,4 +1144,3 @@ B-6  p=1  B-2 7
 B-7  p=1  B-5 2
 
 "
-
