@@ -154,10 +154,13 @@ set_complete_iterator <- function(x, value = TRUE) {
 }
 
 inside_square_error <- function(fn_name, call = rlang::caller_env()) {
-  cli::cli_abort(c(
-    "{.fun {fn_name}} must only be used inside index or vertex sequences like {.code E(g)[]} or {.code V(g)[]}.",
-    i = "See {.help [{.fun [.igraph.es}](igraph::`[.igraph.es`)} or {.help [{.fun [.igraph.vs}](igraph::`[.igraph.vs`)}."
-  ), call = call)
+  cli::cli_abort(
+    c(
+      "{.fun {fn_name}} must only be used inside index or vertex sequences like {.code E(g)[]} or {.code V(g)[]}.",
+      i = "See {.help [{.fun [.igraph.es}](igraph::`[.igraph.es`)} or {.help [{.fun [.igraph.vs}](igraph::`[.igraph.vs`)}."
+    ),
+    call = call
+  )
 }
 
 
@@ -249,14 +252,18 @@ V <- function(graph) {
   update_vs_ref(graph)
 
   res <- seq_len(vcount(graph))
-  if (is_named(graph)) names(res) <- vertex_attr(graph)$name
+  if (is_named(graph)) {
+    names(res) <- vertex_attr(graph)$name
+  }
   class(res) <- "igraph.vs"
   res <- set_complete_iterator(res)
   add_vses_graph_ref(res, graph)
 }
 
 create_vs <- function(graph, idx, na_ok = FALSE) {
-  if (na_ok) idx <- ifelse(idx < 1 | idx > gorder(graph), NA, idx)
+  if (na_ok) {
+    idx <- ifelse(idx < 1 | idx > gorder(graph), NA, idx)
+  }
   res <- simple_vs_index(V(graph), idx, na_ok = na_ok)
   add_vses_graph_ref(res, graph)
 }
@@ -346,7 +353,7 @@ E <- function(graph, P = NULL, path = NULL, directed = TRUE) {
   update_es_ref(graph)
 
   if (!is.null(P) && !is.null(path)) {
-    stop("Cannot give both `P' and `path' at the same time")
+    cli::cli_abort("Cannot use both {.arg P} and {.arg path} at the same time.")
   }
 
   if (is.null(P) && is.null(path)) {
@@ -356,15 +363,21 @@ E <- function(graph, P = NULL, path = NULL, directed = TRUE) {
   } else if (!is.null(P)) {
     on.exit(.Call(R_igraph_finalizer))
     res <- .Call(
-      R_igraph_es_pairs, graph, as_igraph_vs(graph, P) - 1,
+      R_igraph_es_pairs,
+      graph,
+      as_igraph_vs(graph, P) - 1,
       as.logical(directed)
-    ) + 1
+    ) +
+      1
   } else {
     on.exit(.Call(R_igraph_finalizer))
     res <- .Call(
-      R_igraph_es_path, graph, as_igraph_vs(graph, path) - 1,
+      R_igraph_es_path,
+      graph,
+      as_igraph_vs(graph, path) - 1,
       as.logical(directed)
-    ) + 1
+    ) +
+      1
   }
 
   if ("name" %in% edge_attr_names(graph)) {
@@ -380,13 +393,17 @@ E <- function(graph, P = NULL, path = NULL, directed = TRUE) {
 }
 
 create_es <- function(graph, idx, na_ok = FALSE) {
-  if (na_ok) idx <- ifelse(idx < 1 | idx > gsize(graph), NA, idx)
+  if (na_ok) {
+    idx <- ifelse(idx < 1 | idx > gsize(graph), NA, idx)
+  }
   simple_es_index(E(graph), idx)
 }
 
 simple_vs_index <- function(x, i, na_ok = FALSE) {
   res <- unclass(x)[i]
-  if (!na_ok && any(is.na(res))) stop("Unknown vertex selected")
+  if (!na_ok && any(is.na(res))) {
+    cli::cli_abort("Unknown vertex selected.")
+  }
   class(res) <- "igraph.vs"
   res
 }
@@ -441,23 +458,29 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
 #'
 #' @section Special functions:
 #' There are some special igraph functions that can be used only
-#' in expressions indexing vertex sequences: \describe{
-#'   \item{`.nei`}{takes a vertex sequence as its argument
-#'     and selects neighbors of these vertices. An optional `mode`
-#'     argument can be used to select successors (`mode="out"`), or
-#'     predecessors (`mode="in"`) in directed graphs.}
-#'   \item{`.inc`}{Takes an edge sequence as an argument, and
-#'     selects vertices that have at least one incident edge in this
-#'     edge sequence.}
-#'   \item{`.from`}{Similar to `.inc`, but only considers the
-#'     tails of the edges.}
-#'   \item{`.to`}{Similar to `.inc`, but only considers the
-#'     heads of the edges.}
-#'   \item{`.innei`, `.outnei`}{`.innei(v)` is a shorthand for
-#'     `.nei(v, mode = "in")`, and `.outnei(v)` is a shorthand for
-#'     `.nei(v, mode = "out")`.
+#' in expressions indexing vertex sequences:
+#'   \describe{
+#'     \item{`.nei`}{
+#'       takes a vertex sequence as its argument
+#'       and selects neighbors of these vertices.
+#'       An optional `mode` argument can be used to select successors (`mode="out"`),
+#'       or predecessors (`mode="in"`) in directed graphs.
+#'     }
+#'     \item{`.inc`}{
+#'       Takes an edge sequence as an argument,
+#'       and selects vertices that have at least one incident edge in this edge sequence.
+#'     }
+#'     \item{`.from`}{
+#'       Similar to `.inc`, but only considers the tails of the edges.
+#'     }
+#'     \item{`.to`}{
+#'       Similar to `.inc`, but only considers the heads of the edges.
+#'     }
+#'     \item{`.innei`, `.outnei`}{
+#'       `.innei(v)` is a shorthand for `.nei(v, mode = "in")`,
+#'       and `.outnei(v)` is a shorthand for `.nei(v, mode = "out")`.
+#'     }
 #'   }
-#' }
 #' Note that multiple special functions can be used together, or with
 #' regular indices, and then their results are concatenated. See more
 #' examples below.
@@ -525,14 +548,20 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
 
   ## Special case, no argument (but we might get an artificial
   ## empty one
-  if (length(args) < 1 ||
-    (length(args) == 1 && inherits(rlang::quo_get_expr(args[[1]]), "name") &&
-      !nzchar(as.character(rlang::quo_get_expr(args[[1]]))))) {
+  if (
+    length(args) < 1 ||
+      (length(args) == 1 &&
+        inherits(rlang::quo_get_expr(args[[1]]), "name") &&
+        !nzchar(as.character(rlang::quo_get_expr(args[[1]]))))
+  ) {
     return(x)
   }
 
   ## Special case: single numeric argument
-  first_arg_is_numericish <- inherits(rlang::quo_get_expr(args[[1]]), "numeric") ||
+  first_arg_is_numericish <- inherits(
+    rlang::quo_get_expr(args[[1]]),
+    "numeric"
+  ) ||
     inherits(rlang::quo_get_expr(args[[1]]), "integer")
   if (length(args) == 1 && first_arg_is_numericish) {
     res <- simple_vs_index(x, rlang::quo_get_expr(args[[1]]), na_ok)
@@ -542,7 +571,10 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
   ## Special case: single symbol argument, no such attribute
   if (length(args) == 1 && inherits(rlang::quo_get_expr(args[[1]]), "name")) {
     graph <- get_vs_graph(x)
-    if (!(as.character(rlang::quo_get_expr(args[[1]])) %in% vertex_attr_names(graph))) {
+    if (
+      !(as.character(rlang::quo_get_expr(args[[1]])) %in%
+        vertex_attr_names(graph))
+    ) {
       res <- simple_vs_index(x, rlang::eval_tidy(args[[1]]), na_ok)
       return(add_vses_graph_ref(res, graph))
     }
@@ -552,19 +584,17 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
     ## TRUE iff the vertex is a neighbor (any type)
     ## of at least one vertex in v
     mode <- igraph.match.arg(mode)
-    mode <- switch(mode,
-      "out" = 1,
-      "in" = 2,
-      "all" = 3,
-      "total" = 3
-    )
+    mode <- switch(mode, "out" = 1, "in" = 2, "all" = 3, "total" = 3)
 
     if (is.logical(v)) {
       v <- which(v)
     }
     on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      R_igraph_vs_nei, graph, x, as_igraph_vs(graph, v) - 1,
+      R_igraph_vs_nei,
+      graph,
+      x,
+      as_igraph_vs(graph, v) - 1,
       as.numeric(mode)
     )
     tmp[as.numeric(x)]
@@ -592,7 +622,10 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
     }
     on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      R_igraph_vs_adj, graph, x, as_igraph_es(graph, e) - 1,
+      R_igraph_vs_adj,
+      graph,
+      x,
+      as_igraph_es(graph, e) - 1,
       as.numeric(3)
     )
     tmp[as.numeric(x)]
@@ -610,7 +643,10 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
     }
     on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      R_igraph_vs_adj, graph, x, as_igraph_es(graph, e) - 1,
+      R_igraph_vs_adj,
+      graph,
+      x,
+      as_igraph_es(graph, e) - 1,
       as.numeric(1)
     )
     tmp[as.numeric(x)]
@@ -625,7 +661,10 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
     }
     on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      R_igraph_vs_adj, graph, x, as_igraph_es(graph, e) - 1,
+      R_igraph_vs_adj,
+      graph,
+      x,
+      as_igraph_es(graph, e) - 1,
       as.numeric(2)
     )
     tmp[as.numeric(x)]
@@ -646,27 +685,39 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
   } else {
     attrs <- vertex_attr(graph)
     xvec <- as.vector(x)
-    for (i in seq_along(attrs)) attrs[[i]] <- attrs[[i]][xvec]
+    for (i in seq_along(attrs)) {
+      attrs[[i]] <- attrs[[i]][xvec]
+    }
 
     env <- parent.frame()
 
     # Functions (only visible if called or if no duplicate)
     top <- rlang::new_environment(list(
-      .nei = .nei, nei = nei,
-      .innei = .innei, innei = innei,
-      .outnei = .outnei, outnei = outnei,
-      .inc = .inc, inc = inc, adj = adj,
-      .from = .from, from = from,
-      .to = .to, to = to,
+      .nei = .nei,
+      nei = nei,
+      .innei = .innei,
+      innei = innei,
+      .outnei = .outnei,
+      outnei = outnei,
+      .inc = .inc,
+      inc = inc,
+      adj = adj,
+      .from = .from,
+      from = from,
+      .to = .to,
+      to = to,
       .data = list(attrs)
     ))
 
     # Data objects (visible by default)
-    bottom <- rlang::new_environment(parent = top, c(
-      attrs,
-      .env = env,
-      .data = list(attrs)
-    ))
+    bottom <- rlang::new_environment(
+      parent = top,
+      c(
+        attrs,
+        .env = env,
+        .data = list(attrs)
+      )
+    )
 
     data_mask <- rlang::new_data_mask(bottom, top)
 
@@ -676,6 +727,12 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
       if (is.null(ii)) {
         return(NULL)
       }
+      if (is.logical(ii) && (length(ii) != length(x) && length(ii) != 1)) {
+        cli::cli_abort(
+          "Error: Logical index length does not match the number of vertices. Recycling is not allowed."
+        )
+      }
+
       ii <- simple_vs_index(x, ii, na_ok)
       attr(ii, "env") <- attr(x, "env")
       attr(ii, "graph") <- attr(x, "graph")
@@ -785,7 +842,9 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
   } else {
     res <- unclass(x)[i]
   }
-  if (!na_ok && any(is.na(res))) stop("Unknown edge selected")
+  if (!na_ok && any(is.na(res))) {
+    cli::cli_abort("Unknown edge selected")
+  }
   attr(res, "env") <- attr(x, "env")
   attr(res, "graph") <- attr(x, "graph")
   class(res) <- "igraph.es"
@@ -841,26 +900,30 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 #'
 #' @section Special functions:
 #' There are some special igraph functions that can be used
-#' only in expressions indexing edge sequences: \describe{
-#'   \item{`.inc`}{takes a vertex sequence, and selects
-#'     all edges that have at least one incident vertex in the vertex
-#'     sequence.}
-#'   \item{`.from`}{similar to `.inc()`, but only
-#'     the tails of the edges are considered.}
-#'   \item{`.to`}{is similar to `.inc()`, but only
-#'     the heads of the edges are considered.}
-#'   \item{`\%--\%`}{a special operator that can be
-#'     used to select all edges between two sets of vertices. It ignores
-#'     the edge directions in directed graphs.}
-#'   \item{`\%->\%`}{similar to `\%--\%`,
-#'     but edges *from* the left hand side argument, pointing
-#'     *to* the right hand side argument, are selected, in directed
-#'     graphs.}
-#'   \item{`\%<-\%`}{similar to `\%--\%`,
-#'     but edges *to* the left hand side argument, pointing
-#'     *from* the right hand side argument, are selected, in directed
-#'     graphs.}
-#' }
+#' only in expressions indexing edge sequences:
+#'   \describe{
+#'     \item{`.inc`}{
+#'       takes a vertex sequence, and selects all edges that have at least one incident vertex in the vertex sequence.
+#'     }
+#'     \item{`.from`}{
+#'       similar to `.inc()`, but only the tails of the edges are considered.
+#'     }
+#'     \item{`.to`}{
+#'       is similar to `.inc()`, but only the heads of the edges are considered.
+#'     }
+#'     \item{`\%--\%`}{
+#'       a special operator that can be used to select all edges between two sets of vertices.
+#'       It ignores the edge directions in directed graphs.
+#'     }
+#'     \item{`\%->\%`}{
+#'       similar to `\%--\%`, but edges *from* the left hand side argument,
+#'       pointing *to* the right hand side argument, are selected, in directed graphs.
+#'     }
+#'     \item{`\%<-\%`}{
+#'       similar to `\%--\%`, but edges *to* the left hand side argument,
+#'       pointing *from* the right hand side argument, are selected, in directed graphs.
+#'     }
+#'   }
 #' Note that multiple special functions can be used together, or with
 #' regular indices, and then their results are concatenated. See more
 #' examples below.
@@ -908,9 +971,12 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
   ## If indexing has no argument at all, then we still get one,
   ## but it is "empty", a name that is ""
 
-  if (length(args) < 1 ||
-    (length(args) == 1 && inherits(rlang::quo_get_expr(args[[1]]), "name") &&
-      !nzchar(as.character(rlang::quo_get_expr(args[[1]]))))) {
+  if (
+    length(args) < 1 ||
+      (length(args) == 1 &&
+        inherits(rlang::quo_get_expr(args[[1]]), "name") &&
+        !nzchar(as.character(rlang::quo_get_expr(args[[1]]))))
+  ) {
     return(x)
   }
 
@@ -918,7 +984,10 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
     ## TRUE iff the edge is incident to at least one vertex in v
     on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      R_igraph_es_adj, graph, x, as_igraph_vs(graph, v) - 1,
+      R_igraph_es_adj,
+      graph,
+      x,
+      as_igraph_vs(graph, v) - 1,
       as.numeric(3)
     )
     tmp[as.numeric(x)]
@@ -933,7 +1002,10 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
     ## TRUE iff the edge originates from at least one vertex in v
     on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      R_igraph_es_adj, graph, x, as_igraph_vs(graph, v) - 1,
+      R_igraph_es_adj,
+      graph,
+      x,
+      as_igraph_vs(graph, v) - 1,
       as.numeric(1)
     )
     tmp[as.numeric(x)]
@@ -945,7 +1017,10 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
     ## TRUE iff the edge points to at least one vertex in v
     on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      R_igraph_es_adj, graph, x, as_igraph_vs(graph, v) - 1,
+      R_igraph_es_adj,
+      graph,
+      x,
+      as_igraph_vs(graph, v) - 1,
       as.numeric(2)
     )
     tmp[as.numeric(x)]
@@ -961,27 +1036,38 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
   } else {
     attrs <- edge_attr(graph)
     xvec <- as.vector(x)
-    for (i in seq_along(attrs)) attrs[[i]] <- attrs[[i]][xvec]
+    for (i in seq_along(attrs)) {
+      attrs[[i]] <- attrs[[i]][xvec]
+    }
 
     env <- parent.frame()
 
     # Functions (only visible if called or if no duplicate)
     top <- rlang::new_environment(list(
-      .inc = .inc, inc = inc, adj = adj,
-      .from = .from, from = from,
-      .to = .to, to = to,
-      `%--%` = `%--%`, `%->%` = `%->%`, `%<-%` = `%<-%`
+      .inc = .inc,
+      inc = inc,
+      adj = adj,
+      .from = .from,
+      from = from,
+      .to = .to,
+      to = to,
+      `%--%` = `%--%`,
+      `%->%` = `%->%`,
+      `%<-%` = `%<-%`
     ))
 
     # Data objects (visible by default)
-    bottom <- rlang::new_environment(parent = top, c(
-      attrs,
-      .igraph.from = list(.Call(R_igraph_copy_from, graph)[as.numeric(x)]),
-      .igraph.to = list(.Call(R_igraph_copy_to, graph)[as.numeric(x)]),
-      .igraph.graph = list(graph),
-      .env = env,
-      .data = list(attrs)
-    ))
+    bottom <- rlang::new_environment(
+      parent = top,
+      c(
+        attrs,
+        .igraph.from = list(.Call(R_igraph_copy_from, graph)[as.numeric(x)]),
+        .igraph.to = list(.Call(R_igraph_copy_to, graph)[as.numeric(x)]),
+        .igraph.graph = list(graph),
+        .env = env,
+        .data = list(attrs)
+      )
+    )
 
     data_mask <- rlang::new_data_mask(bottom, top)
 
@@ -991,6 +1077,12 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
       if (is.null(ii)) {
         return(NULL)
       }
+      if (is.logical(ii) && (length(ii) != length(x) && length(ii) != 1)) {
+        cli::cli_abort(
+          "Error: Logical index length does not match the number of edges. Recycling is not allowed."
+        )
+      }
+
       ii <- simple_es_index(x, ii)
       attr(ii, "env") <- attr(x, "env")
       attr(ii, "graph") <- attr(x, "graph")
@@ -1052,11 +1144,15 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 #' @name igraph-vs-attributes
 #' @export
 `[[<-.igraph.vs` <- function(x, i, value) {
-  if (!"name" %in% names(attributes(value)) ||
-    !"value" %in% names(attributes(value))) {
-    stop("invalid indexing")
+  if (
+    !"name" %in% names(attributes(value)) ||
+      !"value" %in% names(attributes(value))
+  ) {
+    cli::cli_abort("Invalid indexing.")
+  }
+  if (is.null(get_vs_graph(x))) {
+    stop("Graph is unknown.")
   }
-  if (is.null(get_vs_graph(x))) stop("Graph is unknown")
   value
 }
 
@@ -1070,11 +1166,15 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 #' @name igraph-es-attributes
 #' @export
 `[[<-.igraph.es` <- function(x, i, value) {
-  if (!"name" %in% names(attributes(value)) ||
-    !"value" %in% names(attributes(value))) {
-    stop("invalid indexing")
+  if (
+    !"name" %in% names(attributes(value)) ||
+      !"value" %in% names(attributes(value))
+  ) {
+    stop("Invalid indexing.")
+  }
+  if (is.null(get_es_graph(x))) {
+    stop("Graph is unknown.")
   }
-  if (is.null(get_es_graph(x))) stop("Graph is unknown")
   value
 }
 
@@ -1138,7 +1238,9 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 #' plot(g)
 `$.igraph.vs` <- function(x, name) {
   graph <- get_vs_graph(x)
-  if (is.null(graph)) stop("Graph is unknown")
+  if (is.null(graph)) {
+    cli::cli_abort("Graph is unknown")
+  }
   res <- vertex_attr(graph, name, x)
   if (is_single_index(x)) {
     res[[1]]
@@ -1189,7 +1291,9 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 #' plot(g)
 `$.igraph.es` <- function(x, name) {
   graph <- get_es_graph(x)
-  if (is.null(graph)) stop("Graph is unknown")
+  if (is.null(graph)) {
+    cli::cli_abort("Graph is unknown")
+  }
   res <- edge_attr(graph, name, x)
   if (is_single_index(x)) {
     res[[1]]
@@ -1205,7 +1309,9 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 #' @name igraph-vs-attributes
 #' @export
 `$<-.igraph.vs` <- function(x, name, value) {
-  if (is.null(get_vs_graph(x))) stop("Graph is unknown")
+  if (is.null(get_vs_graph(x))) {
+    cli::cli_abort("Graph is unknown")
+  }
   attr(x, "name") <- name
   attr(x, "value") <- value
   x
@@ -1218,7 +1324,9 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 #' @export
 #' @family vertex and edge sequences
 `$<-.igraph.es` <- function(x, name, value) {
-  if (is.null(get_es_graph(x))) stop("Graph is unknown")
+  if (is.null(get_es_graph(x))) {
+    cli::cli_abort("Graph is unknown")
+  }
   attr(x, "name") <- name
   attr(x, "value") <- value
   x
@@ -1228,13 +1336,18 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 #' @export
 `V<-` <- function(x, value) {
   ensure_igraph(x)
-  if (!"name" %in% names(attributes(value)) ||
-    !"value" %in% names(attributes(value))) {
-    stop("invalid indexing")
+  if (
+    !"name" %in% names(attributes(value)) ||
+      !"value" %in% names(attributes(value))
+  ) {
+    cli::cli_abort("invalid indexing")
   }
-  i_set_vertex_attr(x, attr(value, "name"),
+  i_set_vertex_attr(
+    x,
+    attr(value, "name"),
     index = value,
-    value = attr(value, "value"), check = FALSE
+    value = attr(value, "value"),
+    check = FALSE
   )
 }
 
@@ -1247,13 +1360,18 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 #' @export
 `E<-` <- function(x, path = NULL, P = NULL, directed = NULL, value) {
   ensure_igraph(x)
-  if (!"name" %in% names(attributes(value)) ||
-    !"value" %in% names(attributes(value))) {
-    stop("invalid indexing")
+  if (
+    !"name" %in% names(attributes(value)) ||
+      !"value" %in% names(attributes(value))
+  ) {
+    cli::cli_abort("invalid indexing")
   }
-  i_set_edge_attr(x, attr(value, "name"),
+  i_set_edge_attr(
+    x,
+    attr(value, "name"),
     index = value,
-    value = attr(value, "value"), check = FALSE
+    value = attr(value, "value"),
+    check = FALSE
   )
 }
 
@@ -1298,10 +1416,12 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 #'   set_vertex_attr("color", value = "red")
 #' V(g4)[[]]
 #' V(g4)[[2:5, 7:8]]
-print.igraph.vs <- function(x,
-                            full = igraph_opt("print.full"),
-                            id = igraph_opt("print.id"),
-                            ...) {
+print.igraph.vs <- function(
+  x,
+  full = igraph_opt("print.full"),
+  id = igraph_opt("print.id"),
+  ...
+) {
   graph <- get_vs_graph(x)
   if (!is.null(graph)) {
     vertices <- V(graph)
@@ -1311,23 +1431,34 @@ print.igraph.vs <- function(x,
   len <- length(x)
   gid <- graph_id(x)
 
-  title <- "+ " %+% chr(len) %+% "/" %+%
+  title <- "+ " %+%
+    chr(len) %+%
+    "/" %+%
     (if (is.null(vertices)) "?" else chr(length(vertices))) %+%
     (if (len == 1) " vertex" else " vertices") %+%
     (if (!is.null(names(vertices))) ", named" else "") %+%
-    (if (isTRUE(id) && !is.na(gid)) paste(", from", substr(gid, 1, 7)) else "") %+%
+    (if (isTRUE(id) && !is.na(gid)) {
+      paste(", from", substr(gid, 1, 7))
+    } else {
+      ""
+    }) %+%
     (if (is.null(graph)) " (deleted)" else "") %+%
     ":\n"
   cat(title)
 
-  if (is_single_index(x) && !is.null(graph) && length(vertex_attr_names(graph) > 0)) {
+  if (
+    is_single_index(x) &&
+      !is.null(graph) &&
+      length(vertex_attr_names(graph)) > 0
+  ) {
     ## Double bracket
     va <- vertex_attr(graph)
     if (all(sapply(va, is.atomic))) {
-      print(as.data.frame(va,
-        stringsAsFactors =
-          FALSE
-      )[as.vector(x), , drop = FALSE])
+      print(as.data.frame(va, stringsAsFactors = FALSE)[
+        as.vector(x),
+        ,
+        drop = FALSE
+      ])
     } else {
       print(lapply(va, "[", as.vector(x)))
     }
@@ -1346,9 +1477,11 @@ print.igraph.vs <- function(x,
       if (is.logical(full) && full) {
         print(x2, quote = FALSE)
       } else {
-        head_print(x2,
+        head_print(
+          x2,
           omitted_footer = "+ ... omitted several vertices\n",
-          quote = FALSE, max_lines = igraph_opt("auto.print.lines")
+          quote = FALSE,
+          max_lines = igraph_opt("auto.print.lines")
         )
       }
     }
@@ -1400,15 +1533,21 @@ print.igraph.vs <- function(x,
 #' E(g4)
 #' E(g4)[[]]
 #' E(g4)[[1:5]]
-print.igraph.es <- function(x,
-                            full = igraph_opt("print.full"),
-                            id = igraph_opt("print.id"),
-                            ...) {
+print.igraph.es <- function(
+  x,
+  full = igraph_opt("print.full"),
+  id = igraph_opt("print.id"),
+  ...
+) {
   graph <- get_es_graph(x)
   ml <- if (identical(full, TRUE)) NULL else igraph_opt("auto.print.lines")
   .print.edges.compressed(
-    x = graph, edges = x, max.lines = ml, names = TRUE,
-    num = TRUE, id = id
+    x = graph,
+    edges = x,
+    max.lines = ml,
+    names = TRUE,
+    num = TRUE,
+    id = id
   )
   invisible(x)
 }
@@ -1416,16 +1555,15 @@ print.igraph.es <- function(x,
 # these are internal
 
 as_igraph_vs <- function(graph, v, na.ok = FALSE) {
-  if (inherits(v, "igraph.vs") && !is.null(graph) &&
-    !warn_version(graph)) {
+  if (inherits(v, "igraph.vs") && !is.null(graph) && !warn_version(graph)) {
     if (get_graph_id(graph) != get_vs_graph_id(v)) {
-      stop("Cannot use a vertex sequence from another graph.")
+      cli::cli_abort("Cannot use a vertex sequence from another graph.")
     }
   }
   if (is.character(v) && "name" %in% vertex_attr_names(graph)) {
     v <- as.numeric(match(v, V(graph)$name))
     if (!na.ok && any(is.na(v))) {
-      stop("Invalid vertex names")
+      cli::cli_abort("Invalid vertex names")
     }
     v
   } else {
@@ -1437,17 +1575,16 @@ as_igraph_vs <- function(graph, v, na.ok = FALSE) {
       res <- as.numeric(v)
     }
     if (!na.ok && any(is.na(res))) {
-      stop("Invalid vertex name(s)")
+      cli::cli_abort("Invalid vertex name(s)")
     }
     res
   }
 }
 
 as_igraph_es <- function(graph, e) {
-  if (inherits(e, "igraph.es") && !is.null(graph) &&
-    !warn_version(graph)) {
+  if (inherits(e, "igraph.es") && !is.null(graph) && !warn_version(graph)) {
     if (get_graph_id(graph) != get_es_graph_id(e)) {
-      stop("Cannot use an edge sequence from another graph.")
+      cli::cli_abort("Cannot use an edge sequence from another graph.")
     }
   }
   if (is.character(e)) {
@@ -1460,7 +1597,7 @@ as_igraph_es <- function(graph, e) {
       vv <- strsplit(e[Pairs], "|", fixed = TRUE)
       vl <- sapply(vv, length)
       if (any(vl != 2)) {
-        stop("Invalid edge name: ", e[Pairs][vl != 2][1])
+        cli::cli_abort("Invalid edge name: ", e[Pairs][vl != 2][1])
       }
       vp <- unlist(vv)
       if (!"name" %in% vertex_attr_names(graph)) {
@@ -1481,7 +1618,7 @@ as_igraph_es <- function(graph, e) {
     res <- as.numeric(e)
   }
   if (any(is.na(res))) {
-    stop("Invalid edge names")
+    cli::cli_abort("Invalid edge names")
   }
   res
 }
@@ -1500,7 +1637,9 @@ is_igraph_es <- function(x) {
 parse_op_args <- function(..., what, is_fun, as_fun, check_graph = TRUE) {
   args <- list(...)
 
-  if (any(!sapply(args, is_fun))) stop("Not ", what, " sequence")
+  if (any(!sapply(args, is_fun))) {
+    cli::cli_abort("Not {what} sequence")
+  }
 
   ## get the ids of all graphs
   graph_id <- sapply(args, get_vs_graph_id) %>%
@@ -1537,16 +1676,20 @@ parse_op_args <- function(..., what, is_fun, as_fun, check_graph = TRUE) {
 
 
 parse_vs_op_args <- function(...) {
-  parse_op_args(...,
-    what = "a vertex", is_fun = is_igraph_vs,
+  parse_op_args(
+    ...,
+    what = "a vertex",
+    is_fun = is_igraph_vs,
     as_fun = as_igraph_vs
   )
 }
 
 
 parse_es_op_args <- function(...) {
-  parse_op_args(...,
-    what = "an edge", is_fun = is_igraph_es,
+  parse_op_args(
+    ...,
+    what = "an edge",
+    is_fun = is_igraph_es,
     as_fun = as_igraph_es
   )
 }
@@ -1556,8 +1699,10 @@ create_op_result <- function(parsed, result, class, args) {
   result <- add_vses_graph_ref(result, parsed$graph)
   class(result) <- class
   ## c() drops names for zero length vectors. Why???
-  if (!length(result) &&
-    any(sapply(args, function(x) !is.null(names(x))))) {
+  if (
+    !length(result) &&
+      any(sapply(args, function(x) !is.null(names(x))))
+  ) {
     names(result) <- character()
   }
   result
