@@ -1,15 +1,15 @@
-
 #' Triad census, subgraphs with three vertices
 #'
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `triad.census()` was renamed to `triad_census()` to create a more
+#' `triad.census()` was renamed to [triad_census()] to create a more
 #' consistent API.
 #' @inheritParams triad_census
 #' @keywords internal
 #' @export
-triad.census <- function(graph) { # nocov start
+triad.census <- function(graph) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "triad.census()", "triad_census()")
   triad_census(graph = graph)
 } # nocov end
@@ -19,12 +19,13 @@ triad.census <- function(graph) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `graph.motifs.no()` was renamed to `count_motifs()` to create a more
+#' `graph.motifs.no()` was renamed to [count_motifs()] to create a more
 #' consistent API.
 #' @inheritParams count_motifs
 #' @keywords internal
 #' @export
-graph.motifs.no <- function(graph, size = 3, cut.prob = rep(0, size)) { # nocov start
+graph.motifs.no <- function(graph, size = 3, cut.prob = rep(0, size)) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "graph.motifs.no()", "count_motifs()")
   count_motifs(graph = graph, size = size, cut.prob = cut.prob)
 } # nocov end
@@ -34,14 +35,31 @@ graph.motifs.no <- function(graph, size = 3, cut.prob = rep(0, size)) { # nocov
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `graph.motifs.est()` was renamed to `sample_motifs()` to create a more
+#' `graph.motifs.est()` was renamed to [sample_motifs()] to create a more
 #' consistent API.
+#' @param cut.prob Numeric vector giving the probabilities that the search
+#'   graph is cut at a certain level. Its length should be the same as the size
+#'   of the motif (the `size` argument).
+#'   If `rep(0, size))`, the default, no cuts are made.
 #' @inheritParams sample_motifs
 #' @keywords internal
 #' @export
-graph.motifs.est <- function(graph, size = 3, cut.prob = rep(0, size), sample.size = vcount(graph) / 10, sample = NULL) { # nocov start
+graph.motifs.est <- function(
+  graph,
+  size = 3,
+  cut.prob = rep(0, size),
+  sample.size = vcount(graph) / 10,
+  sample = NULL
+) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "graph.motifs.est()", "sample_motifs()")
-  sample_motifs(graph = graph, size = size, cut.prob = cut.prob, sample.size = sample.size, sample = sample)
+  sample_motifs(
+    graph = graph,
+    size = size,
+    cut.prob = cut.prob,
+    sample.size = sample.size,
+    sample = sample
+  )
 } # nocov end
 
 #' Graph motifs
@@ -49,12 +67,17 @@ graph.motifs.est <- function(graph, size = 3, cut.prob = rep(0, size), sample.si
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `graph.motifs()` was renamed to `motifs()` to create a more
+#' `graph.motifs()` was renamed to [motifs()] to create a more
 #' consistent API.
+#' @param cut.prob Numeric vector giving the probabilities that the search
+#'   graph is cut at a certain level. Its length should be the same as the size
+#'   of the motif (the `size` argument).
+#'   If `rep(0, size))`, the default, no cuts are made.
 #' @inheritParams motifs
 #' @keywords internal
 #' @export
-graph.motifs <- function(graph, size = 3, cut.prob = rep(0, size)) { # nocov start
+graph.motifs <- function(graph, size = 3, cut.prob = rep(0, size)) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "graph.motifs()", "motifs()")
   motifs(graph = graph, size = size, cut.prob = cut.prob)
 } # nocov end
@@ -64,12 +87,13 @@ graph.motifs <- function(graph, size = 3, cut.prob = rep(0, size)) { # nocov sta
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `dyad.census()` was renamed to `dyad_census()` to create a more
+#' `dyad.census()` was renamed to [dyad_census()] to create a more
 #' consistent API.
 #' @inheritParams dyad_census
 #' @keywords internal
 #' @export
-dyad.census <- function(graph) { # nocov start
+dyad.census <- function(graph) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "dyad.census()", "dyad_census()")
   dyad_census(graph = graph)
 } # nocov end
@@ -110,7 +134,8 @@ dyad.census <- function(graph) { # nocov start
 #'   directed graphs and sizes 3-6 in undirected graphs.
 #' @param cut.prob Numeric vector giving the probabilities that the search
 #'   graph is cut at a certain level. Its length should be the same as the size
-#'   of the motif (the `size` argument). By default no cuts are made.
+#'   of the motif (the `size` argument).
+#'   If `NULL`, the default, no cuts are made.
 #' @return `motifs()` returns a numeric vector, the number of occurrences of
 #'   each motif in the graph. The motifs are ordered by their isomorphism
 #'   classes. Note that for unconnected subgraphs, which are not considered to be
@@ -125,20 +150,23 @@ dyad.census <- function(graph) { # nocov start
 #' motifs(g, 3)
 #' count_motifs(g, 3)
 #' sample_motifs(g, 3)
-motifs <- function(graph, size = 3, cut.prob = rep(0, size)) {
+motifs <- function(graph, size = 3, cut.prob = NULL) {
   ensure_igraph(graph)
-  cut.prob <- as.numeric(cut.prob)
-  if (length(cut.prob) != size) {
-    cut.prob <- c(
-      cut.prob[-length(cut.prob)],
-      rep(cut.prob[-length(cut.prob)], length(cut.prob) - 1)
-    )
+
+  if (!is.null(cut.prob)) {
+    cut.prob <- as.numeric(cut.prob)
+  }
+
+  if (!is.null(cut.prob) && length(cut.prob) != size) {
+    cli::cli_abort("{arg cut.prob} must be the same length as {.arg size}")
   }
 
   on.exit(.Call(R_igraph_finalizer))
   res <- .Call(
-    R_igraph_motifs_randesu, graph, as.numeric(size),
-    as.numeric(cut.prob)
+    R_igraph_motifs_randesu,
+    graph,
+    as.numeric(size),
+    cut.prob
   )
   res[is.nan(res)] <- NA
   res
@@ -156,7 +184,8 @@ motifs <- function(graph, size = 3, cut.prob = rep(0, size)) {
 #' @param size The size of the motif.
 #' @param cut.prob Numeric vector giving the probabilities that the search
 #'   graph is cut at a certain level. Its length should be the same as the size
-#'   of the motif (the `size` argument). By default no cuts are made.
+#'   of the motif (the `size` argument).
+#'   If `NULL`, the default, no cuts are made.
 #' @return `count_motifs()` returns  a numeric scalar.
 #' @seealso [isomorphism_class()]
 #'
@@ -168,20 +197,23 @@ motifs <- function(graph, size = 3, cut.prob = rep(0, size)) {
 #' motifs(g, 3)
 #' count_motifs(g, 3)
 #' sample_motifs(g, 3)
-count_motifs <- function(graph, size = 3, cut.prob = rep(0, size)) {
+count_motifs <- function(graph, size = 3, cut.prob = NULL) {
   ensure_igraph(graph)
-  cut.prob <- as.numeric(cut.prob)
-  if (length(cut.prob) != size) {
-    cut.prob <- c(
-      cut.prob[-length(cut.prob)],
-      rep(cut.prob[-length(cut.prob)], length(cut.prob) - 1)
-    )
+
+  if (!is.null(cut.prob)) {
+    cut.prob <- as.numeric(cut.prob)
+  }
+
+  if (!is.null(cut.prob) && length(cut.prob) != size) {
+    cli::cli_abort("{arg cut.prob} must be the same length as {.arg size}")
   }
 
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_motifs_randesu_no, graph, as.numeric(size),
-    as.numeric(cut.prob)
+    R_igraph_motifs_randesu_no,
+    graph,
+    as.numeric(size),
+    cut.prob
   )
 }
 
@@ -198,7 +230,8 @@ count_motifs <- function(graph, size = 3, cut.prob = rep(0, size)) {
 #'   in directed graphs and sizes 3-6 in undirected graphs.
 #' @param cut.prob Numeric vector giving the probabilities that the search
 #'   graph is cut at a certain level. Its length should be the same as the size
-#'   of the motif (the `size` argument). By default no cuts are made.
+#'   of the motif (the `size` argument).
+#'   If `NULL`, the default, no cuts are made.
 #' @param sample.size The number of vertices to use as a starting point for
 #'   finding motifs. Only used if the `sample` argument is `NULL`.
 #'   The default is `ceiling(vcount(graph) / 10)` .
@@ -224,17 +257,18 @@ sample_motifs <- function(
   sample = NULL
 ) {
   ensure_igraph(graph)
-  cut.prob <- as.numeric(cut.prob)
-  if (length(cut.prob) != size) {
-    cut.prob <- c(
-      cut.prob[-length(cut.prob)],
-      rep(cut.prob[-length(cut.prob)], length(cut.prob) - 1)
-    )
+
+  if (!is.null(cut.prob)) {
+    cut.prob <- as.numeric(cut.prob)
+  }
+
+  if (!is.null(cut.prob) && length(cut.prob) != size) {
+    cli::cli_abort("{arg cut.prob} must be the same length as {.arg size}")
   }
 
   if (is.null(sample)) {
     if (is.null(sample.size)) {
-       sample.size <- ceiling(vcount(graph) / 10)
+      sample.size <- ceiling(vcount(graph) / 10)
     }
   } else {
     sample <- as_igraph_vs(graph, sample) - 1
@@ -243,8 +277,12 @@ sample_motifs <- function(
 
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_motifs_randesu_estimate, graph, as.numeric(size),
-    as.numeric(cut.prob), as.numeric(sample.size), sample
+    R_igraph_motifs_randesu_estimate,
+    graph,
+    as.numeric(size),
+    cut.prob,
+    as.numeric(sample.size),
+    sample
   )
 }
 
@@ -257,10 +295,18 @@ sample_motifs <- function(
 #'
 #'
 #' @param graph The input graph. A warning is given if it is not directed.
-#' @return A named numeric vector with three elements: \item{mut}{The number of
-#'   pairs with mutual connections.} \item{asym}{The number of pairs with
-#'   non-mutual connections.} \item{null}{The number of pairs with no connection
-#'   between them.}
+#' @return A named numeric vector with three elements:
+#'   \describe{
+#'     \item{mut}{
+#'       The number of pairs with mutual connections.
+#'     }
+#'     \item{asym}{
+#'       The number of pairs with non-mutual connections.
+#'     }
+#'     \item{null}{
+#'       The number of pairs with no connection between them.
+#'     }
+#'   }
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @seealso [triad_census()] for the same classification, but with
 #' triples.
@@ -294,15 +340,57 @@ dyad_census <- function(graph) {
 #'
 #' Triad census was defined by David and Leinhardt (see References below).
 #' Every triple of vertices (A, B, C) are classified into the 16 possible
-#' states: \describe{ \item{003}{A,B,C, the empty graph.} \item{012}{A->B, C,
-#' the graph with a single directed edge.} \item{102}{A<->B, C, the graph with
-#' a mutual connection between two vertices.} \item{021D}{A<-B->C, the
-#' out-star.} \item{021U}{A->B<-C, the in-star.} \item{021C}{A->B->C, directed
-#' line.} \item{111D}{A<->B<-C.} \item{111U}{A<->B->C.} \item{030T}{A->B<-C,
-#' A->C.} \item{030C}{A<-B<-C, A->C.} \item{201}{A<->B<->C.}
-#' \item{120D}{A<-B->C, A<->C.} \item{120U}{A->B<-C, A<->C.}
-#' \item{120C}{A->B->C, A<->C.} \item{210}{A->B<->C, A<->C.}
-#' \item{300}{A<->B<->C, A<->C, the complete graph.} }
+#' states:
+#'   \describe{
+#'     \item{003}{
+#'       A,B,C, the empty graph.
+#'     }
+#'     \item{012}{
+#'       A->B, C, the graph with a single directed edge.
+#'     }
+#'     \item{102}{
+#'       A<->B, C, the graph with a mutual connection between two vertices.
+#'     }
+#'     \item{021D}{
+#'       A<-B->C, the out-star.
+#'     }
+#'     \item{021U}{
+#'       A->B<-C, the in-star.
+#'     }
+#'     \item{021C}{
+#'       A->B->C, directed line.
+#'     }
+#'     \item{111D}{
+#'       A<->B<-C.
+#'     }
+#'     \item{111U}{
+#'       A<->B->C.
+#'     }
+#'     \item{030T}{
+#'       A->B<-C, A->C.
+#'     }
+#'     \item{030C}{
+#'       A<-B<-C, A->C.
+#'     }
+#'     \item{201}{
+#'       A<->B<->C.
+#'     }
+#'     \item{120D}{
+#'       A<-B->C, A<->C.
+#'     }
+#'     \item{120U}{
+#'       A->B<-C, A<->C.
+#'     }
+#'     \item{120C}{
+#'       A->B->C, A<->C.
+#'     }
+#'     \item{210}{
+#'       A->B<->C, A<->C.
+#'     }
+#'     \item{300}{
+#'       A<->B<->C, A<->C, the complete graph.
+#'     }
+#'   }
 #'
 #' This functions uses the RANDESU motif finder algorithm to find and count the
 #' subgraphs, see [motifs()].
