@@ -1,15 +1,15 @@
-
 #' Permute the vertices of a graph
 #'
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `permute.vertices()` was renamed to `permute()` to create a more
+#' `permute.vertices()` was renamed to [permute()] to create a more
 #' consistent API.
 #' @inheritParams permute
 #' @keywords internal
 #' @export
-permute.vertices <- function(graph, permutation) { # nocov start
+permute.vertices <- function(graph, permutation) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "permute.vertices()", "permute()")
   permute(graph = graph, permutation = permutation)
 } # nocov end
@@ -19,14 +19,23 @@ permute.vertices <- function(graph, permutation) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `graph.isocreate()` was renamed to `graph_from_isomorphism_class()` to create a more
+#' `graph.isocreate()` was renamed to [graph_from_isomorphism_class()] to create a more
 #' consistent API.
 #' @inheritParams graph_from_isomorphism_class
 #' @keywords internal
 #' @export
-graph.isocreate <- function(size, number, directed = TRUE) { # nocov start
-  lifecycle::deprecate_soft("2.0.0", "graph.isocreate()", "graph_from_isomorphism_class()")
-  graph_from_isomorphism_class(size = size, number = number, directed = directed)
+graph.isocreate <- function(size, number, directed = TRUE) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "graph.isocreate()",
+    "graph_from_isomorphism_class()"
+  )
+  graph_from_isomorphism_class(
+    size = size,
+    number = number,
+    directed = directed
+  )
 } # nocov end
 
 #' Number of automorphisms
@@ -34,13 +43,22 @@ graph.isocreate <- function(size, number, directed = TRUE) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `graph.automorphisms()` was renamed to `count_automorphisms()` to create a more
+#' `graph.automorphisms()` was renamed to [count_automorphisms()] to create a more
 #' consistent API.
 #' @inheritParams count_automorphisms
 #' @keywords internal
 #' @export
-graph.automorphisms <- function(graph, colors = NULL, sh = c("fm", "f", "fs", "fl", "flm", "fsm")) { # nocov start
-  lifecycle::deprecate_soft("2.0.0", "graph.automorphisms()", "count_automorphisms()")
+graph.automorphisms <- function(
+  graph,
+  colors = NULL,
+  sh = c("fm", "f", "fs", "fl", "flm", "fsm")
+) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "graph.automorphisms()",
+    "count_automorphisms()"
+  )
   count_automorphisms(graph = graph, colors = colors, sh = sh)
 } # nocov end
 
@@ -49,13 +67,22 @@ graph.automorphisms <- function(graph, colors = NULL, sh = c("fm", "f", "fs", "f
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `canonical.permutation()` was renamed to `canonical_permutation()` to create a more
+#' `canonical.permutation()` was renamed to [canonical_permutation()] to create a more
 #' consistent API.
 #' @inheritParams canonical_permutation
 #' @keywords internal
 #' @export
-canonical.permutation <- function(graph, colors = NULL, sh = c("fm", "f", "fs", "fl", "flm", "fsm")) { # nocov start
-  lifecycle::deprecate_soft("2.0.0", "canonical.permutation()", "canonical_permutation()")
+canonical.permutation <- function(
+  graph,
+  colors = NULL,
+  sh = c("fm", "f", "fs", "fl", "flm", "fsm")
+) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "canonical.permutation()",
+    "canonical_permutation()"
+  )
   canonical_permutation(graph = graph, colors = colors, sh = sh)
 } # nocov end
 
@@ -64,12 +91,17 @@ canonical.permutation <- function(graph, colors = NULL, sh = c("fm", "f", "fs",
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `automorphisms()` was renamed to `count_automorphisms()` to create a more
+#' `automorphisms()` was renamed to [count_automorphisms()] to create a more
 #' consistent API.
 #' @inheritParams count_automorphisms
 #' @keywords internal
 #' @export
-automorphisms <- function(graph, colors = NULL, sh = c("fm", "f", "fs", "fl", "flm", "fsm")) { # nocov start
+automorphisms <- function(
+  graph,
+  colors = NULL,
+  sh = c("fm", "f", "fs", "fl", "flm", "fsm")
+) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "automorphisms()", "count_automorphisms()")
   count_automorphisms(graph = graph, colors = colors, sh = sh)
 } # nocov end
@@ -96,9 +128,14 @@ automorphisms <- function(graph, colors = NULL, sh = c("fm", "f", "fs", "fl", "f
 ###################################################################
 
 #' @export
-graph.get.isomorphisms.vf2 <- function(graph1, graph2, vertex.color1,
-                                       vertex.color2, edge.color1,
-                                       edge.color2) {
+graph.get.isomorphisms.vf2 <- function(
+  graph1,
+  graph2,
+  vertex.color1,
+  vertex.color2,
+  edge.color1,
+  edge.color2
+) {
   # Argument checks
   ensure_igraph(graph1)
   ensure_igraph(graph2)
@@ -146,17 +183,27 @@ graph.get.isomorphisms.vf2 <- function(graph1, graph2, vertex.color1,
   on.exit(.Call(R_igraph_finalizer))
   # Function call
   res <- .Call(
-    R_igraph_get_isomorphisms_vf2, graph1, graph2, vertex.color1,
-    vertex.color2, edge.color1, edge.color2
+    R_igraph_get_isomorphisms_vf2,
+    graph1,
+    graph2,
+    vertex.color1,
+    vertex.color2,
+    edge.color1,
+    edge.color2
   )
 
   lapply(res, function(.x) V(graph2)[.x + 1])
 }
 
 #' @export
-graph.get.subisomorphisms.vf2 <- function(graph1, graph2, vertex.color1,
-                                          vertex.color2, edge.color1,
-                                          edge.color2) {
+graph.get.subisomorphisms.vf2 <- function(
+  graph1,
+  graph2,
+  vertex.color1,
+  vertex.color2,
+  edge.color1,
+  edge.color2
+) {
   # Argument checks
   ensure_igraph(graph1)
   ensure_igraph(graph2)
@@ -204,8 +251,13 @@ graph.get.subisomorphisms.vf2 <- function(graph1, graph2, vertex.color1,
   on.exit(.Call(R_igraph_finalizer))
   # Function call
   res <- .Call(
-    R_igraph_get_subisomorphisms_vf2, graph1, graph2,
-    vertex.color1, vertex.color2, edge.color1, edge.color2
+    R_igraph_get_subisomorphisms_vf2,
+    graph1,
+    graph2,
+    vertex.color1,
+    vertex.color2,
+    edge.color1,
+    edge.color2
   )
 
   lapply(res, function(.x) V(graph1)[.x + 1])
@@ -224,9 +276,15 @@ graph.isoclass.subgraph <- function(graph, vids) {
 }
 
 #' @export
-graph.subisomorphic.lad <- function(pattern, target, domains = NULL,
-                                    induced = FALSE, map = TRUE, all.maps = FALSE,
-                                    time.limit = Inf) {
+graph.subisomorphic.lad <- function(
+  pattern,
+  target,
+  domains = NULL,
+  induced = FALSE,
+  map = TRUE,
+  all.maps = FALSE,
+  time.limit = Inf
+) {
   # Argument checks
   ensure_igraph(pattern)
   ensure_igraph(target)
@@ -240,10 +298,14 @@ graph.subisomorphic.lad <- function(pattern, target, domains = NULL,
   all.maps <- as.logical(all.maps)
   if (!is.null(domains)) {
     if (!is.list(domains)) {
-      stop("`domains' must be a list of vertex vectors from `target'")
+      cli::cli_abort(
+        "{.arg domains} must be a list of vertex vectors from {.arg target}."
+      )
     }
     if (length(domains) != vcount(pattern)) {
-      stop("`domains' length and `pattern' number of vertices must match")
+      cli::cli_abort(
+        "{.arg domains} length and {.arg pattern} number of vertices must match."
+      )
     }
     domains <- lapply(domains, function(x) as_igraph_vs(target, x) - 1)
   }
@@ -251,8 +313,14 @@ graph.subisomorphic.lad <- function(pattern, target, domains = NULL,
   on.exit(.Call(R_igraph_finalizer))
   # Function call
   res <- .Call(
-    R_igraph_subisomorphic_lad, pattern, target, domains,
-    induced, time.limit, map, all.maps
+    R_igraph_subisomorphic_lad,
+    pattern,
+    target,
+    domains,
+    induced,
+    time.limit,
+    map,
+    all.maps
   )
 
   if (map) {
@@ -261,7 +329,9 @@ graph.subisomorphic.lad <- function(pattern, target, domains = NULL,
       names(res$map) <- V(target)$name[res$map]
     }
   }
-  if (all.maps) res$maps <- lapply(res$maps, function(.x) V(target)[.x + 1])
+  if (all.maps) {
+    res$maps <- lapply(res$maps, function(.x) V(target)[.x + 1])
+  }
 
   res
 }
@@ -294,18 +364,18 @@ graph.subisomorphic.lad <- function(pattern, target, domains = NULL,
 #' references below. It supports vertex and edge colors and have the
 #' following extra arguments:
 #' \describe{
-#'   \item{vertex.color1, vertex.color2}{Optional integer vectors giving the
-#'     colors of the vertices for colored graph isomorphism. If they
-#'     are not given, but the graph has a \dQuote{color} vertex attribute,
-#'     then it will be used. If you want to ignore these attributes, then
-#'     supply `NULL` for both of these arguments. See also examples
-#'     below.}
-#'   \item{edge.color1, edge.color2}{Optional integer vectors giving the
-#'     colors of the edges for edge-colored (sub)graph isomorphism. If they
-#'     are not given, but the graph has a \dQuote{color} edge attribute,
-#'     then it will be used. If you want to ignore these attributes, then
-#'     supply `NULL` for both of these arguments.}
-#' }
+#'     \item{vertex.color1, vertex.color2}{
+#'       Optional integer vectors giving the colors of the vertices for colored graph isomorphism.
+#'       If they are not given, but the graph has a \dQuote{color} vertex attribute, then it will be used.
+#'       If you want to ignore these attributes, then supply `NULL` for both of these arguments.
+#'       See also examples below.
+#'     }
+#'     \item{edge.color1, edge.color2}{
+#'       Optional integer vectors giving the colors of the edges for edge-colored (sub)graph isomorphism.
+#'       If they are not given, but the graph has a \dQuote{color} edge attribute, then it will be used.
+#'       If you want to ignore these attributes, then supply `NULL` for both of these arguments.
+#'     }
+#'   }
 #'
 #' @section \sQuote{bliss} method:
 #' Uses the BLISS algorithm by Junttila and Kaski, and it works for
@@ -315,10 +385,10 @@ graph.subisomorphic.lad <- function(pattern, target, domains = NULL,
 #' canonical forms are compared.
 #' Extra arguments:
 #' \describe{
-#'   \item{sh}{Character constant, the heuristics to use in the BLISS
-#'     algorithm for `graph1` and `graph2`. See the `sh` argument of
-#'     [canonical_permutation()] for possible values.}
-#' }
+#'     \item{sh}{
+#'       Character constant, the heuristics to use in the BLISS algorithm for `graph1` and `graph2`. See the `sh` argument of [canonical_permutation()] for possible values.
+#'     }
+#'   }
 #' `sh` defaults to \sQuote{fm}.
 #'
 #' @param graph1 The first graph.
@@ -372,10 +442,17 @@ graph.subisomorphic.lad <- function(pattern, target, domains = NULL,
 #'   vertex.color1 = NULL,
 #'   vertex.color2 = NULL
 #' )
-isomorphic <- function(graph1, graph2, method = c(
-                         "auto", "direct",
-                         "vf2", "bliss"
-                       ), ...) {
+isomorphic <- function(
+  graph1,
+  graph2,
+  method = c(
+    "auto",
+    "direct",
+    "vf2",
+    "bliss"
+  ),
+  ...
+) {
   ensure_igraph(graph1)
   ensure_igraph(graph2)
   method <- igraph.match.arg(method)
@@ -418,35 +495,40 @@ is_isomorphic_to <- isomorphic
 #' This is the LAD algorithm by Solnon, see the reference below. It has
 #' the following extra arguments:
 #' \describe{
-#'   \item{domains}{If not `NULL`, then it specifies matching
-#'     restrictions. It must be a list of `target` vertex sets, given
-#'     as numeric vertex ids or symbolic vertex names. The length of the
-#'     list must be `vcount(pattern)` and for each vertex in
-#'     `pattern` it gives the allowed matching vertices in
-#'     `target`. Defaults to `NULL`.}
-#'   \item{induced}{Logical scalar, whether to search for an induced
-#'     subgraph. It is `FALSE` by default.}
-#'   \item{time.limit}{The processor time limit for the computation, in
-#'     seconds. It defaults to `Inf`, which means no limit.}
-#' }
+#'     \item{domains}{
+#'       If not `NULL`, then it specifies matching restrictions.
+#'       It must be a list of `target` vertex sets, given as numeric vertex ids or symbolic vertex names.
+#'       The length of the list must be `vcount(pattern)` and for each vertex in `pattern`
+#'       it gives the allowed matching vertices in `target`.
+#'       Defaults to `NULL`.
+#'     }
+#'     \item{induced}{
+#'       Logical scalar, whether to search for an induced subgraph.
+#'       It is `FALSE` by default.
+#'     }
+#'     \item{time.limit}{
+#'       The processor time limit for the computation, in seconds.
+#'       It defaults to `Inf`, which means no limit.
+#'     }
+#'   }
 #'
 #' @section \sQuote{vf2} method:
 #' This method uses the VF2 algorithm by Cordella, Foggia et al., see
 #' references below. It supports vertex and edge colors and have the
 #' following extra arguments:
 #' \describe{
-#'   \item{vertex.color1, vertex.color2}{Optional integer vectors giving the
-#'     colors of the vertices for colored graph isomorphism. If they
-#'     are not given, but the graph has a \dQuote{color} vertex attribute,
-#'     then it will be used. If you want to ignore these attributes, then
-#'     supply `NULL` for both of these arguments. See also examples
-#'     below.}
-#'   \item{edge.color1, edge.color2}{Optional integer vectors giving the
-#'     colors of the edges for edge-colored (sub)graph isomorphism. If they
-#'     are not given, but the graph has a \dQuote{color} edge attribute,
-#'     then it will be used. If you want to ignore these attributes, then
-#'     supply `NULL` for both of these arguments.}
-#' }
+#'     \item{vertex.color1, vertex.color2}{
+#'       Optional integer vectors giving the colors of the vertices for colored graph isomorphism.
+#'       If they are not given, but the graph has a \dQuote{color} vertex attribute, then it will be used.
+#'       If you want to ignore these attributes, then supply `NULL` for both of these arguments.
+#'       See also examples below.
+#'     }
+#'     \item{edge.color1, edge.color2}{
+#'       Optional integer vectors giving the colors of the edges for edge-colored (sub)graph isomorphism.
+#'       If they are not given, but the graph has a \dQuote{color} edge attribute, then it will be used.
+#'       If you want to ignore these attributes, then supply `NULL` for both of these arguments.
+#'     }
+#'   }
 #'
 #' @param pattern The smaller graph, it might be directed or
 #'   undirected. Undirected graphs are treated as directed graphs with
@@ -496,15 +578,24 @@ is_isomorphic_to <- isomorphic
 #' pattern <- make_graph(~ 1:2:3, 1 -+ 2:3)
 #' dring <- make_ring(10, directed = TRUE)
 #' subgraph_isomorphic(pattern, dring)
-subgraph_isomorphic <- function(pattern, target,
-                                method = c("auto", "lad", "vf2"), ...) {
+subgraph_isomorphic <- function(
+  pattern,
+  target,
+  method = c("auto", "lad", "vf2"),
+  ...
+) {
   method <- igraph.match.arg(method)
 
-  if (method == "auto") method <- "lad"
+  if (method == "auto") {
+    method <- "lad"
+  }
 
   if (method == "lad") {
-    graph.subisomorphic.lad(pattern, target,
-      map = FALSE, all.maps = FALSE,
+    graph.subisomorphic.lad(
+      pattern,
+      target,
+      map = FALSE,
+      all.maps = FALSE,
       ...
     )$iso
   } else if (method == "vf2") {
@@ -570,35 +661,38 @@ graph.count.isomorphisms.vf2 <- count_isomorphisms_vf2_impl
 #' This is the LAD algorithm by Solnon, see the reference below. It has
 #' the following extra arguments:
 #' \describe{
-#'   \item{domains}{If not `NULL`, then it specifies matching
-#'     restrictions. It must be a list of `target` vertex sets, given
-#'     as numeric vertex ids or symbolic vertex names. The length of the
-#'     list must be `vcount(pattern)` and for each vertex in
-#'     `pattern` it gives the allowed matching vertices in
-#'     `target`. Defaults to `NULL`.}
-#'   \item{induced}{Logical scalar, whether to search for an induced
-#'     subgraph. It is `FALSE` by default.}
-#'   \item{time.limit}{The processor time limit for the computation, in
-#'     seconds. It defaults to `Inf`, which means no limit.}
-#' }
+#'     \item{domains}{
+#'       If not `NULL`, then it specifies matching restrictions.
+#'       It must be a list of `target` vertex sets, given as numeric vertex ids or symbolic vertex names.
+#'       The length of the list must be `vcount(pattern)` and for each vertex in `pattern`
+#'       it gives the allowed matching vertices in `target`.
+#'       Defaults to `NULL`.
+#'     }
+#'     \item{induced}{
+#'       Logical scalar, whether to search for an induced subgraph. It is `FALSE` by default.
+#'     }
+#'     \item{time.limit}{
+#'       The processor time limit for the computation, in seconds. It defaults to `Inf`, which means no limit.
+#'     }
+#'   }
 #'
 #' @section \sQuote{vf2} method:
 #' This method uses the VF2 algorithm by Cordella, Foggia et al., see
 #' references below. It supports vertex and edge colors and have the
 #' following extra arguments:
 #' \describe{
-#'   \item{vertex.color1, vertex.color2}{Optional integer vectors giving the
-#'     colors of the vertices for colored graph isomorphism. If they
-#'     are not given, but the graph has a \dQuote{color} vertex attribute,
-#'     then it will be used. If you want to ignore these attributes, then
-#'     supply `NULL` for both of these arguments. See also examples
-#'     below.}
-#'   \item{edge.color1, edge.color2}{Optional integer vectors giving the
-#'     colors of the edges for edge-colored (sub)graph isomorphism. If they
-#'     are not given, but the graph has a \dQuote{color} edge attribute,
-#'     then it will be used. If you want to ignore these attributes, then
-#'     supply `NULL` for both of these arguments.}
-#' }
+#'     \item{vertex.color1, vertex.color2}{
+#'       Optional integer vectors giving the colors of the vertices for colored graph isomorphism.
+#'       If they are not given, but the graph has a \dQuote{color} vertex attribute, then it will be used.
+#'       If you want to ignore these attributes, then supply `NULL` for both of these arguments.
+#'       See also examples below.
+#'     }
+#'     \item{edge.color1, edge.color2}{
+#'       Optional integer vectors giving the colors of the edges for edge-colored (sub)graph isomorphism.
+#'       If they are not given, but the graph has a \dQuote{color} edge attribute, then it will be used.
+#'       If you want to ignore these attributes, then supply `NULL` for both of these arguments.
+#'     }
+#'   }
 #'
 #' @param pattern The smaller graph, it might be directed or
 #'   undirected. Undirected graphs are treated as directed graphs with
@@ -624,8 +718,12 @@ graph.count.isomorphisms.vf2 <- count_isomorphisms_vf2_impl
 #'
 #' @export
 #' @family graph isomorphism
-count_subgraph_isomorphisms <- function(pattern, target,
-                                        method = c("lad", "vf2"), ...) {
+count_subgraph_isomorphisms <- function(
+  pattern,
+  target,
+  method = c("lad", "vf2"),
+  ...
+) {
   method <- igraph.match.arg(method)
 
   if (method == "lad") {
@@ -668,35 +766,40 @@ isomorphisms <- function(graph1, graph2, method = "vf2", ...) {
 #' This is the LAD algorithm by Solnon, see the reference below. It has
 #' the following extra arguments:
 #' \describe{
-#'   \item{domains}{If not `NULL`, then it specifies matching
-#'     restrictions. It must be a list of `target` vertex sets, given
-#'     as numeric vertex ids or symbolic vertex names. The length of the
-#'     list must be `vcount(pattern)` and for each vertex in
-#'     `pattern` it gives the allowed matching vertices in
-#'     `target`. Defaults to `NULL`.}
-#'   \item{induced}{Logical scalar, whether to search for an induced
-#'     subgraph. It is `FALSE` by default.}
-#'   \item{time.limit}{The processor time limit for the computation, in
-#'     seconds. It defaults to `Inf`, which means no limit.}
-#' }
+#'     \item{domains}{
+#'       If not `NULL`, then it specifies matching restrictions.
+#'       It must be a list of `target` vertex sets, given as numeric vertex ids or symbolic vertex names.
+#'       The length of the list must be `vcount(pattern)` and for each vertex in `pattern`
+#'       it gives the allowed matching vertices in `target`.
+#'       Defaults to `NULL`.
+#'     }
+#'     \item{induced}{
+#'       Logical scalar, whether to search for an induced subgraph.
+#'       It is `FALSE` by default.
+#'     }
+#'     \item{time.limit}{
+#'       The processor time limit for the computation, in seconds.
+#'       It defaults to `Inf`, which means no limit.
+#'     }
+#'   }
 #'
 #' @section \sQuote{vf2} method:
 #' This method uses the VF2 algorithm by Cordella, Foggia et al., see
 #' references below. It supports vertex and edge colors and have the
 #' following extra arguments:
 #' \describe{
-#'   \item{vertex.color1, vertex.color2}{Optional integer vectors giving the
-#'     colors of the vertices for colored graph isomorphism. If they
-#'     are not given, but the graph has a \dQuote{color} vertex attribute,
-#'     then it will be used. If you want to ignore these attributes, then
-#'     supply `NULL` for both of these arguments. See also examples
-#'     below.}
-#'   \item{edge.color1, edge.color2}{Optional integer vectors giving the
-#'     colors of the edges for edge-colored (sub)graph isomorphism. If they
-#'     are not given, but the graph has a \dQuote{color} edge attribute,
-#'     then it will be used. If you want to ignore these attributes, then
-#'     supply `NULL` for both of these arguments.}
-#' }
+#'     \item{vertex.color1, vertex.color2}{
+#'       Optional integer vectors giving the colors of the vertices for colored graph isomorphism.
+#'       If they are not given, but the graph has a \dQuote{color} vertex attribute, then it will be used.
+#'       If you want to ignore these attributes, then supply `NULL` for both of these arguments.
+#'       See also examples below.
+#'     }
+#'     \item{edge.color1, edge.color2}{
+#'       Optional integer vectors giving the colors of the edges for edge-colored (sub)graph isomorphism.
+#'       If they are not given, but the graph has a \dQuote{color} edge attribute, then it will be used.
+#'       If you want to ignore these attributes, then supply `NULL` for both of these arguments.
+#'     }
+#'   }
 #'
 #' @param pattern The smaller graph, it might be directed or
 #'   undirected. Undirected graphs are treated as directed graphs with
@@ -714,8 +817,12 @@ isomorphisms <- function(graph1, graph2, method = "vf2", ...) {
 #'
 #' @export
 #' @family graph isomorphism
-subgraph_isomorphisms <- function(pattern, target,
-                                  method = c("lad", "vf2"), ...) {
+subgraph_isomorphisms <- function(
+  pattern,
+  target,
+  method = c("lad", "vf2"),
+  ...
+) {
   method <- igraph.match.arg(method)
 
   if (method == "lad") {
@@ -776,7 +883,6 @@ graph.isoclass <- isoclass_impl
 #' @return An igraph object, the graph of the given size, directedness
 #'   and isomorphism class.
 #'
-#'
 #' @family graph isomorphism
 #' @export
 #' @cdocs igraph_isoclass_create
@@ -795,13 +901,28 @@ graph_from_isomorphism_class <- isoclass_create_impl
 #' See the paper below for the details about BLISS. This and more information
 #' is available at <http://www.tcs.hut.fi/Software/bliss/index.html>.
 #'
-#' The possible values for the `sh` argument are: \describe{
-#' \item{"f"}{First non-singleton cell.} \item{"fl"}{First largest
-#' non-singleton cell.} \item{"fs"}{First smallest non-singleton cell.}
-#' \item{"fm"}{First maximally non-trivially connectec non-singleton
-#' cell.} \item{"flm"}{Largest maximally non-trivially connected
-#' non-singleton cell.} \item{"fsm"}{Smallest maximally non-trivially
-#' connected non-singleton cell.} } See the paper in references for details
+#' The possible values for the `sh` argument are:
+#' \describe{
+#'     \item{"f"}{
+#'       First non-singleton cell.
+#'     }
+#'     \item{"fl"}{
+#'       First largest non-singleton cell.
+#'     }
+#'     \item{"fs"}{
+#'       First smallest non-singleton cell.
+#'     }
+#'     \item{"fm"}{
+#'       First maximally non-trivially connectec non-singleton cell.
+#'     }
+#'     \item{"flm"}{
+#'       Largest maximally non-trivially connected non-singleton cell.
+#'     }
+#'     \item{"fsm"}{
+#'       Smallest maximally non-trivially connected non-singleton cell.
+#'     }
+#'   }
+#' See the paper in references for details
 #' about these.
 #'
 #' @param graph The input graph, treated as undirected.
@@ -813,19 +934,38 @@ graph_from_isomorphism_class <- isoclass_create_impl
 #'   `color` vertex attribute but you do not want to use it.
 #' @param sh Type of the heuristics to use for the BLISS algorithm. See details
 #'   for possible values.
-#' @return A list with the following members: \item{labeling}{The canonical
-#'   permutation which takes the input graph into canonical form. A numeric
-#'   vector, the first element is the new label of vertex 0, the second element
-#'   for vertex 1, etc. } \item{info}{Some information about the BLISS
-#'   computation. A named list with the following members: \describe{
-#'   \item{"nof_nodes"}{The number of nodes in the search tree.}
-#'   \item{"nof_leaf_nodes"}{The number of leaf nodes in the search tree.}
-#'   \item{"nof_bad_nodes"}{Number of bad nodes.}
-#'   \item{"nof_canupdates"}{Number of canrep updates.}
-#'   \item{"max_level"}{Maximum level.} \item{"group_size"}{The size
-#'   of the automorphism group of the input graph, as a string. The string
-#'   representation is necessary because the group size can easily exceed
-#'   values that are exactly representable in floating point.} } }
+#' @return A list with the following members:
+#'   \describe{
+#'     \item{labeling}{
+#'       The canonical permutation which takes the input graph into canonical form.
+#'       A numeric vector, the first element is the new label of vertex 0, the second element for vertex 1, etc.
+#'     }
+#'     \item{info}{
+#'       Some information about the BLISS computation. A named list with the following members:
+#'         \describe{
+#'           \item{"nof_nodes"}{
+#'             The number of nodes in the search tree.
+#'           }
+#'           \item{"nof_leaf_nodes"}{
+#'             The number of leaf nodes in the search tree.
+#'           }
+#'           \item{"nof_bad_nodes"}{
+#'             Number of bad nodes.
+#'           }
+#'           \item{"nof_canupdates"}{
+#'             Number of canrep updates.
+#'           }
+#'           \item{"max_level"}{
+#'             Maximum level.
+#'           }
+#'           \item{"group_size"}{
+#'             The size of the automorphism group of the input graph, as a string.
+#'             The string representation is necessary because the group size
+#'             can easily exceed values that are exactly representable in floating point.
+#'           }
+#'         }
+#'     }
+#'   }
 #' @author Tommi Junttila for BLISS, Gabor Csardi
 #' \email{csardi.gabor@@gmail.com} for the igraph and R interfaces.
 #' @seealso [permute()] to apply a permutation to a graph,
@@ -927,20 +1067,44 @@ graph.isomorphic <- isomorphic_impl
 #'   all vertices have the same color. Pass NULL explicitly if the graph has a
 #'   `color` vertex attribute but you do not want to use it.
 #' @param sh The splitting heuristics for the BLISS algorithm. Possible values
-#'   are: \sQuote{`f`}: first non-singleton cell, \sQuote{`fl`}: first
-#'   largest non-singleton cell, \sQuote{`fs`}: first smallest non-singleton
-#'   cell, \sQuote{`fm`}: first maximally non-trivially connected
-#'   non-singleton cell, \sQuote{`flm`}: first largest maximally
-#'   non-trivially connected non-singleton cell, \sQuote{`fsm`}: first
-#'   smallest maximally non-trivially connected non-singleton cell.
-#' @return A named list with the following members: \item{group_size}{The size
-#'   of the automorphism group of the input graph, as a string. This number is
-#'   exact if igraph was compiled with the GMP library, and approximate
-#'   otherwise.} \item{nof_nodes}{The number of nodes in the search tree.}
-#'   \item{nof_leaf_nodes}{The number of leaf nodes in the search tree.}
-#'   \item{nof_bad_nodes}{Number of bad nodes.} \item{nof_canupdates}{Number of
-#'   canrep updates.} \item{max_level}{Maximum level.}
-#' @author Tommi Junttila (<http://users.ics.aalto.fi/tjunttil/>) for BLISS
+#'   are:
+#'   \sQuote{`f`}:
+#'     first non-singleton cell,
+#'   \sQuote{`fl`}:
+#'     first largest non-singleton cell,
+#'   \sQuote{`fs`}:
+#'     first smallest non-singleton cell,
+#'   \sQuote{`fm`}:
+#'     first maximally non-trivially connected
+#'     non-singleton cell,
+#'   \sQuote{`flm`}:
+#'     first largest maximally
+#'     non-trivially connected non-singleton cell,
+#'   \sQuote{`fsm`}:
+#'     first smallest maximally non-trivially connected non-singleton cell.
+#' @return A named list with the following members:
+#'   \describe{
+#'     \item{group_size}{
+#'       The size of the automorphism group of the input graph, as a string.
+#'       This number is exact if igraph was compiled with the GMP library, and approximate otherwise.
+#'     }
+#'     \item{nof_nodes}{
+#'       The number of nodes in the search tree.
+#'     }
+#'     \item{nof_leaf_nodes}{
+#'       The number of leaf nodes in the search tree.
+#'     }
+#'     \item{nof_bad_nodes}{
+#'       Number of bad nodes.
+#'     }
+#'     \item{nof_canupdates}{
+#'       Number of canrep updates.
+#'     }
+#'     \item{max_level}{
+#'       Maximum level.
+#'     }
+#'   }
+#' @author Tommi Junttila (<https://users.ics.aalto.fi/tjunttil/>) for BLISS
 #' and Gabor Csardi \email{csardi.gabor@@gmail.com} for the igraph glue code
 #' and this manual page.
 #' @seealso [canonical_permutation()], [permute()],
@@ -992,21 +1156,36 @@ count_automorphisms <- count_automorphisms_impl
 #'   all vertices have the same color. Pass NULL explicitly if the graph has a
 #'   `color` vertex attribute but you do not want to use it.
 #' @param sh The splitting heuristics for the BLISS algorithm. Possible values
-#'   are: \sQuote{`f`}: first non-singleton cell, \sQuote{`fl`}: first
-#'   largest non-singleton cell, \sQuote{`fs`}: first smallest non-singleton
-#'   cell, \sQuote{`fm`}: first maximally non-trivially connected
-#'   non-singleton cell, \sQuote{`flm`}: first largest maximally
-#'   non-trivially connected non-singleton cell, \sQuote{`fsm`}: first
-#'   smallest maximally non-trivially connected non-singleton cell.
+#'   are:
+#'   \sQuote{`f`}:
+#'     first non-singleton cell,
+#'   \sQuote{`fl`}:
+#'     first largest non-singleton cell,
+#'   \sQuote{`fs`}:
+#'     first smallest non-singleton cell,
+#'   \sQuote{`fm`}:
+#'     first maximally non-trivially connected
+#'     non-singleton cell,
+#'   \sQuote{`flm`}:
+#'     first largest maximally
+#'     non-trivially connected non-singleton cell,
+#'   \sQuote{`fsm`}:
+#'     first smallest maximally non-trivially connected non-singleton cell.
 #' @param details Specifies whether to provide additional details about the
 #'   BLISS internals in the result.
 #' @return When `details` is `FALSE`, a list of vertex permutations
 #'   that form a generating set of the automorphism group of the input graph.
 #'   When `details` is `TRUE`, a named list with two members:
-#'   \item{generators}{Returns the generators themselves} \item{info}{Additional
-#'   information about the BLISS internals. See [count_automorphisms()] for
-#'   more details.}
-#' @author Tommi Junttila (<http://users.ics.aalto.fi/tjunttil/>) for BLISS,
+#'   \describe{
+#'     \item{generators}{
+#'       Returns the generators themselves
+#'     }
+#'     \item{info}{
+#'       Additional information about the BLISS internals.
+#'       See [count_automorphisms()] for more details.
+#'     }
+#'   }
+#' @author Tommi Junttila (<https://users.ics.aalto.fi/tjunttil/>) for BLISS,
 #' Gabor Csardi \email{csardi.gabor@@gmail.com} for the igraph glue code and
 #' Tamas Nepusz \email{ntamas@@gmail.com} for this manual page.
 #' @seealso [canonical_permutation()], [permute()],
