@@ -1,16 +1,20 @@
-
 #' Find triangles in graphs
 #'
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `adjacent.triangles()` was renamed to `count_triangles()` to create a more
+#' `adjacent.triangles()` was renamed to [count_triangles()] to create a more
 #' consistent API.
 #' @inheritParams count_triangles
 #' @keywords internal
 #' @export
-adjacent.triangles <- function(graph, vids = V(graph)) { # nocov start
-  lifecycle::deprecate_soft("2.0.0", "adjacent.triangles()", "count_triangles()")
+adjacent.triangles <- function(graph, vids = V(graph)) {
+  # nocov start
+  lifecycle::deprecate_soft(
+    "2.0.0",
+    "adjacent.triangles()",
+    "count_triangles()"
+  )
   count_triangles(graph = graph, vids = vids)
 } # nocov end
 
@@ -37,7 +41,6 @@ adjacent.triangles <- function(graph, vids = V(graph)) { # nocov start
 ##
 ## -----------------------------------------------------------------------
 
-
 #' Find triangles in graphs
 #'
 #' Count how many triangles a vertex is part of, in a graph, or just list the
@@ -91,4 +94,4 @@ triangles <- list_triangles_impl
 #' @export
 #' @rdname count_triangles
 #' @cdocs igraph_adjacent_triangles
-count_triangles <- adjacent_triangles_impl
+count_triangles <- count_adjacent_triangles_impl
