@@ -2,14 +2,20 @@ test_that("subgraph_centrality() works", {
   frucht_graph <- make_graph("Frucht")
   expect_equal(
     subgraph_centrality(frucht_graph),
-    Matrix::diag(Matrix::expm(as_adjacency_matrix(frucht_graph, sparse = FALSE))),
+    Matrix::diag(Matrix::expm(as_adjacency_matrix(
+      frucht_graph,
+      sparse = FALSE
+    ))),
     tolerance = 1e-10
   )
 
   grotzsch_graph <- make_graph("Grotzsch")
   expect_equal(
     subgraph_centrality(grotzsch_graph),
-    Matrix::diag(Matrix::expm(as_adjacency_matrix(grotzsch_graph, sparse = FALSE))),
+    Matrix::diag(Matrix::expm(as_adjacency_matrix(
+      grotzsch_graph,
+      sparse = FALSE
+    ))),
     tolerance = 1e-10
   )
 })
@@ -36,17 +42,22 @@ test_that("`authority_score()` works", {
   }
 
   g1 <- make_graph(
-    c(1, 3, 1, 6, 1, 10, 2, 1, 3, 1, 4, 2, 4, 7, 4, 9, 5, 4, 5, 6, 5, 8, 6, 3,
-      7, 1, 7, 5, 7, 6, 7, 10, 8, 4, 9, 6, 10, 5, 10, 7),
-    directed = TRUE)
+    c(
+      1, 3, 1, 6, 1, 10, 2, 1, 3, 1, 4, 2, 4, 7, 4, 9, 5, 4, 5, 6, 5, 8, 6, 3,
+      7, 1, 7, 5, 7, 6, 7, 10, 8, 4, 9, 6, 10, 5, 10, 7
+    ),
+    directed = TRUE
+  )
   A <- as_adjacency_matrix(g1, sparse = FALSE)
   s1 <- eigen(t(A) %*% A)$vectors[, 1]
   s2 <- authority_score(g1)$vector
   expect_equal(
     s2,
-    c(0.519632767970952, 0.0191587307007462, 0.327572049088003,
+    c(
+      0.519632767970952, 0.0191587307007462, 0.327572049088003,
       0.238728053455971, 0.449690304629051, 1, 0.0966933781044594,
-      0.204851318050036, 0.0191587307007462, 0.653243552177761)
+      0.204851318050036, 0.0191587307007462, 0.653243552177761
+    )
   )
   expect_equal(mscale(s1), mscale(s2), ignore_attr = TRUE)
 
@@ -59,8 +70,10 @@ test_that("`authority_score()` works", {
   s2 <- authority_score(g2)$vector
   expect_equal(
     s2,
-    c(0.763521118433368, 1, 0.546200349457202,
-      0.918985947228995, 0.28462967654657)
+    c(
+      0.763521118433368, 1, 0.546200349457202,
+      0.918985947228995, 0.28462967654657
+    )
   )
   expect_equal(mscale(s1), mscale(s2), ignore_attr = TRUE)
 
@@ -85,17 +98,22 @@ test_that("`hub_score()` works", {
   }
 
   g1 <- make_graph(
-    c(1, 3, 1, 6, 1, 10, 2, 1, 3, 1, 4, 2, 4, 7, 4, 9, 5, 4, 5, 6, 5, 8, 6, 3,
-      7, 1, 7, 5, 7, 6, 7, 10, 8, 4, 9, 6, 10, 5, 10, 7),
-    directed = TRUE)
+    c(
+      1, 3, 1, 6, 1, 10, 2, 1, 3, 1, 4, 2, 4, 7, 4, 9, 5, 4, 5, 6, 5, 8, 6, 3,
+      7, 1, 7, 5, 7, 6, 7, 10, 8, 4, 9, 6, 10, 5, 10, 7
+    ),
+    directed = TRUE
+  )
   A <- as_adjacency_matrix(g1, sparse = FALSE)
   s1 <- eigen(A %*% t(A))$vectors[, 1]
   s2 <- hub_score(g1)$vector
   expect_equal(
     s2,
-    c(0.755296579522977, 0.198139015063149, 0.198139015063149,
+    c(
+      0.755296579522977, 0.198139015063149, 0.198139015063149,
       0.0514804231207635, 0.550445261472941, 0.124905139108053,
-      1, 0.0910284037021176, 0.381305851509012, 0.208339295395331)
+      1, 0.0910284037021176, 0.381305851509012, 0.208339295395331
+    )
   )
   expect_equal(mscale(s1), mscale(s2), ignore_attr = TRUE)
 
@@ -108,8 +126,10 @@ test_that("`hub_score()` works", {
   s2 <- hub_score(g2)$vector
   expect_equal(
     s2,
-    c(1, 0.763521118433368, 0.546200349457203,
-      0.28462967654657, 0.918985947228995)
+    c(
+      1, 0.763521118433368, 0.546200349457203,
+      0.28462967654657, 0.918985947228995
+    )
   )
   expect_equal(mscale(s1), mscale(s2), ignore_attr = TRUE)
 
@@ -126,31 +146,28 @@ test_that("authority_score survives stress test", {
 
   withr::local_seed(42)
 
-  is.principal <- function(M, lambda) {
+  expect_principal <- function(M, lambda) {
     expect_equal(eigen(M)$values[1], lambda)
   }
 
-  is.ev <- function(M, v, lambda) {
+  expect_ev <- function(M, v, lambda) {
     expect_equal(as.vector(M %*% v), lambda * v)
   }
 
-  is.good <- function(M, v, lambda) {
-    is.principal(M, lambda)
-    is.ev(M, v, lambda)
+  expect_good <- function(M, v, lambda) {
+    expect_principal(M, lambda)
+    expect_ev(M, v, lambda)
   }
 
   for (i in 1:100) {
-    G <- sample_gnm(10, sample(1:20, 1))
-    as <- hits_scores(G)
-    M <- as_adjacency_matrix(G, sparse = FALSE)
-    is.good(t(M) %*% M, as$authority, as$value)
-  }
-
-  for (i in 1:100) {
-    G <- sample_gnm(10, sample(1:20, 1))
+    repeat {
+      G <- sample_gnm(10, sample(15:25, 1), directed = FALSE)
+      if (is_connected(G)) break
+    }
+    G <- as_directed(G, mode = "mutual")
     hs <- hits_scores(G)
     M <- as_adjacency_matrix(G, sparse = FALSE)
-    is.good(M %*% t(M), hs$hub, hs$value)
+    expect_good(M %*% t(M), hs$hub, hs$value)
   }
 })
 
@@ -166,17 +183,22 @@ test_that("`hits_score()` works -- authority", {
   }
 
   g1 <- make_graph(
-    c(1, 3, 1, 6, 1, 10, 2, 1, 3, 1, 4, 2, 4, 7, 4, 9, 5, 4, 5, 6, 5, 8, 6, 3,
-      7, 1, 7, 5, 7, 6, 7, 10, 8, 4, 9, 6, 10, 5, 10, 7),
-    directed = TRUE)
+    c(
+      1, 3, 1, 6, 1, 10, 2, 1, 3, 1, 4, 2, 4, 7, 4, 9, 5, 4, 5, 6, 5, 8, 6, 3,
+      7, 1, 7, 5, 7, 6, 7, 10, 8, 4, 9, 6, 10, 5, 10, 7
+    ),
+    directed = TRUE
+  )
   A <- as_adjacency_matrix(g1, sparse = FALSE)
   s1 <- eigen(t(A) %*% A)$vectors[, 1]
   s2 <- hits_scores(g1)$authority
   expect_equal(
     s2,
-    c(0.519632767970952, 0.0191587307007462, 0.327572049088003,
+    c(
+      0.519632767970952, 0.0191587307007462, 0.327572049088003,
       0.238728053455971, 0.449690304629051, 1, 0.0966933781044594,
-      0.204851318050036, 0.0191587307007462, 0.653243552177761)
+      0.204851318050036, 0.0191587307007462, 0.653243552177761
+    )
   )
   expect_equal(mscale(s1), mscale(s2), ignore_attr = TRUE)
 
@@ -189,11 +211,12 @@ test_that("`hits_score()` works -- authority", {
   s2 <- hits_scores(g2)$authority
   expect_equal(
     s2,
-    c(0.763521118433368, 1, 0.546200349457202,
-      0.918985947228995, 0.28462967654657)
+    c(
+      0.763521118433368, 1, 0.546200349457202,
+      0.918985947228995, 0.28462967654657
+    )
   )
   expect_equal(mscale(s1), mscale(s2), ignore_attr = TRUE)
-
 })
 
 test_that("`hits_scores()` works -- hub", {
@@ -208,17 +231,22 @@ test_that("`hits_scores()` works -- hub", {
   }
 
   g1 <- make_graph(
-    c(1, 3, 1, 6, 1, 10, 2, 1, 3, 1, 4, 2, 4, 7, 4, 9, 5, 4, 5, 6, 5, 8, 6, 3,
-      7, 1, 7, 5, 7, 6, 7, 10, 8, 4, 9, 6, 10, 5, 10, 7),
-    directed = TRUE)
+    c(
+      1, 3, 1, 6, 1, 10, 2, 1, 3, 1, 4, 2, 4, 7, 4, 9, 5, 4, 5, 6, 5, 8, 6, 3,
+      7, 1, 7, 5, 7, 6, 7, 10, 8, 4, 9, 6, 10, 5, 10, 7
+    ),
+    directed = TRUE
+  )
   A <- as_adjacency_matrix(g1, sparse = FALSE)
   s1 <- eigen(A %*% t(A))$vectors[, 1]
   s2 <- hits_scores(g1)$hub
   expect_equal(
     s2,
-    c(0.755296579522977, 0.198139015063149, 0.198139015063149,
+    c(
+      0.755296579522977, 0.198139015063149, 0.198139015063149,
       0.0514804231207635, 0.550445261472941, 0.124905139108053,
-      1, 0.0910284037021176, 0.381305851509012, 0.208339295395331)
+      1, 0.0910284037021176, 0.381305851509012, 0.208339295395331
+    )
   )
   expect_equal(mscale(s1), mscale(s2), ignore_attr = TRUE)
 
@@ -228,14 +256,15 @@ test_that("`hits_scores()` works -- hub", {
   )
   A <- as_adjacency_matrix(g2, sparse = FALSE)
   s1 <- eigen(A %*% t(A))$vectors[, 1]
-  s2 <-  hits_scores(g2)$hub
+  s2 <- hits_scores(g2)$hub
   expect_equal(
     s2,
-    c(1, 0.763521118433368, 0.546200349457203,
-      0.28462967654657, 0.918985947228995)
+    c(
+      1, 0.763521118433368, 0.546200349457203,
+      0.28462967654657, 0.918985947228995
+    )
   )
   expect_equal(mscale(s1), mscale(s2), ignore_attr = TRUE)
-
 })
 
 test_that("betweenness() works for kite graph", {
@@ -254,7 +283,13 @@ test_that("betweenness() works for kite graph", {
   nf <- (vcount(kite) - 1) * (vcount(kite) - 2) / 2
   bet <- structure(betweenness(kite) / nf, names = V(kite)$name)
   bet <- round(sort(bet, decreasing = TRUE), 3)
-  expect_equal(bet, structure(c(0.389, 0.231, 0.231, 0.222, 0.102, 0.023, 0.023, 0.000, 0.000, 0.000), names = c("Heather", "Fernando", "Garth", "Ike", "Diane", "Andre", "Beverly", "Carol", "Ed", "Jane")))
+  expect_equal(
+    bet,
+    structure(
+      c(0.389, 0.231, 0.231, 0.222, 0.102, 0.023, 0.023, 0.000, 0.000, 0.000),
+      names = c("Heather", "Fernando", "Garth", "Ike", "Diane", "Andre", "Beverly", "Carol", "Ed", "Jane")
+    )
+  )
 
   bet2 <- structure(betweenness(kite, normalized = TRUE), names = V(kite)$name)
   bet2 <- round(sort(bet2, decreasing = TRUE), 3)
@@ -289,7 +324,7 @@ test_that("weighted betweenness() works", {
 })
 
 test_that("betweenness()'s normalization works well", {
-  g1 <- graph_from_literal(0 + -+1 + -+2)
+  g1 <- graph_from_literal(0 +-+ 1 +-+ 2)
 
   b11 <- betweenness(g1, normalized = TRUE, directed = FALSE)
   expect_equal(b11, c("0" = 0, "1" = 1, "2" = 0))
@@ -297,7 +332,7 @@ test_that("betweenness()'s normalization works well", {
   b12 <- betweenness(g1, normalized = TRUE, directed = TRUE)
   expect_equal(b12, c("0" = 0, "1" = 1, "2" = 0))
 
-  g2 <- graph_from_literal(0 - --1 - --2)
+  g2 <- graph_from_literal(0 --- 1 --- 2)
 
   b2 <- betweenness(g2, normalized = TRUE)
   expect_equal(b2, c("0" = 0, "1" = 1, "2" = 0))
@@ -324,7 +359,10 @@ test_that("betweenness() -- shortest paths are compared with tolerance when calc
   g <- graph_from_data_frame(edges, directed = FALSE)
   result <- betweenness(g, weights = edges.dists)
 
-  expect_equal(result[1:5], c("1" = 0, "2" = 44, "3" = 71, "4" = 36.5, "6" = 44))
+  expect_equal(
+    result[1:5],
+    c("1" = 0, "2" = 44, "3" = 71, "4" = 36.5, "6" = 44)
+  )
 })
 
 test_that("edge_betweenness() works", {
@@ -414,30 +452,80 @@ test_that("closeness() centralization works", {
 
 test_that("power_centrality() works", {
   ## Generate some test data from Bonacich, 1987:
-  fig1 <- graph_from_literal(A - +B - +C:D)
+  fig1 <- graph_from_literal(A -+ B -+ C:D)
   fig1.bp <- lapply(seq(0, 0.8, by = 0.2), function(x) {
     round(power_centrality(fig1, exponent = x), 2)
   })
-  expect_equal(fig1.bp, list(c(A = 0.89, B = 1.79, C = 0, D = 0), c(A = 1.15, B = 1.64, C = 0, D = 0), c(A = 1.34, B = 1.49, C = 0, D = 0), c(A = 1.48, B = 1.35, C = 0, D = 0), c(A = 1.59, B = 1.22, C = 0, D = 0)))
+  expect_equal(
+    fig1.bp,
+    list(
+      c(A = 0.89, B = 1.79, C = 0, D = 0),
+      c(A = 1.15, B = 1.64, C = 0, D = 0),
+      c(A = 1.34, B = 1.49, C = 0, D = 0),
+      c(A = 1.48, B = 1.35, C = 0, D = 0),
+      c(A = 1.59, B = 1.22, C = 0, D = 0)
+    )
+  )
 
   g.c <- make_graph(c(1, 2, 1, 3, 2, 4, 3, 5), dir = FALSE)
   bp.c <- lapply(seq(-.5, .5, by = 0.1), function(x) {
     round(power_centrality(g.c, exponent = x), 2)[c(1, 2, 4)]
   })
 
-  expect_equal(bp.c, list(c(0.00, 1.58, 0.00), c(0.73, 1.45, 0.36), c(0.97, 1.34, 0.49), c(1.09, 1.27, 0.54), c(1.15, 1.23, 0.58), c(1.20, 1.20, 0.60), c(1.22, 1.17, 0.61), c(1.25, 1.16, 0.62), c(1.26, 1.14, 0.63), c(1.27, 1.13, 0.64), c(1.28, 1.12, 0.64)))
+  expect_equal(
+    bp.c,
+    list(
+      c(0.00, 1.58, 0.00),
+      c(0.73, 1.45, 0.36),
+      c(0.97, 1.34, 0.49),
+      c(1.09, 1.27, 0.54),
+      c(1.15, 1.23, 0.58),
+      c(1.20, 1.20, 0.60),
+      c(1.22, 1.17, 0.61),
+      c(1.25, 1.16, 0.62),
+      c(1.26, 1.14, 0.63),
+      c(1.27, 1.13, 0.64),
+      c(1.28, 1.12, 0.64)
+    )
+  )
 
   g.d <- make_graph(c(1, 2, 1, 3, 1, 4, 2, 5, 3, 6, 4, 7), dir = FALSE)
   bp.d <- lapply(seq(-.4, .4, by = 0.1), function(x) {
     round(power_centrality(g.d, exponent = x), 2)[c(1, 2, 5)]
   })
-  expect_equal(bp.d, list(c(1.62, 1.08, 0.54), c(1.62, 1.08, 0.54), c(1.62, 1.08, 0.54), c(1.62, 1.08, 0.54), c(1.62, 1.08, 0.54), c(1.62, 1.08, 0.54), c(1.62, 1.08, 0.54), c(1.62, 1.08, 0.54), c(1.62, 1.08, 0.54)))
+  expect_equal(
+    bp.d,
+    list(
+      c(1.62, 1.08, 0.54),
+      c(1.62, 1.08, 0.54),
+      c(1.62, 1.08, 0.54),
+      c(1.62, 1.08, 0.54),
+      c(1.62, 1.08, 0.54),
+      c(1.62, 1.08, 0.54),
+      c(1.62, 1.08, 0.54),
+      c(1.62, 1.08, 0.54),
+      c(1.62, 1.08, 0.54)
+    )
+  )
 
   g.e <- make_graph(c(1, 2, 1, 3, 1, 4, 2, 5, 2, 6, 3, 7, 3, 8, 4, 9, 4, 10), dir = FALSE)
   bp.e <- lapply(seq(-.4, .4, by = 0.1), function(x) {
     round(power_centrality(g.e, exponent = x), 2)[c(1, 2, 5)]
   })
-  expect_equal(bp.e, list(c(-1.00, 1.67, -0.33), c(0.36, 1.81, 0.12), c(1.00, 1.67, 0.33), c(1.30, 1.55, 0.43), c(1.46, 1.46, 0.49), c(1.57, 1.40, 0.52), c(1.63, 1.36, 0.54), c(1.68, 1.33, 0.56), c(1.72, 1.30, 0.57)))
+  expect_equal(
+    bp.e,
+    list(
+      c(-1.00, 1.67, -0.33),
+      c(0.36, 1.81, 0.12),
+      c(1.00, 1.67, 0.33),
+      c(1.30, 1.55, 0.43),
+      c(1.46, 1.46, 0.49),
+      c(1.57, 1.40, 0.52),
+      c(1.63, 1.36, 0.54),
+      c(1.68, 1.33, 0.56),
+      c(1.72, 1.30, 0.57)
+    )
+  )
 
   g.f <- make_graph(c(1, 2, 1, 3, 1, 4, 2, 5, 2, 6, 2, 7, 3, 8, 3, 9, 3, 10, 4, 11, 4, 12, 4, 13),
     dir = FALSE
@@ -447,7 +535,17 @@ test_that("power_centrality() works", {
   })
   expect_equal(
     bp.f,
-    list(c(-1.72, 1.53, -0.57), c(-0.55, 2.03, -0.18), c(0.44, 2.05, 0.15), c(1.01, 1.91, 0.34), c(1.33, 1.78, 0.44), c(1.52, 1.67, 0.51), c(1.65, 1.59, 0.55), c(1.74, 1.53, 0.58), c(1.80, 1.48, 0.60))
+    list(
+      c(-1.72, 1.53, -0.57),
+      c(-0.55, 2.03, -0.18),
+      c(0.44, 2.05, 0.15),
+      c(1.01, 1.91, 0.34),
+      c(1.33, 1.78, 0.44),
+      c(1.52, 1.67, 0.51),
+      c(1.65, 1.59, 0.55),
+      c(1.74, 1.53, 0.58),
+      c(1.80, 1.48, 0.60)
+    )
   )
 })
 
@@ -465,27 +563,39 @@ test_that("eigen_centrality() works", {
     Jane - Ike
   )
   evc <- round(eigen_centrality(kite)$vector, 3)
-  expect_equal(evc, structure(c(0.732, 0.732, 0.594, 1, 0.827, 0.594, 0.827, 0.407, 0.1, 0.023), .Names = c("Andre", "Beverly", "Carol", "Diane", "Fernando", "Ed", "Garth", "Heather", "Ike", "Jane")))
-
+  expect_equal(
+    evc,
+    structure(
+      c(0.732, 0.732, 0.594, 1, 0.827, 0.594, 0.827, 0.407, 0.1, 0.023),
+      .Names = c("Andre", "Beverly", "Carol", "Diane", "Fernando", "Ed", "Garth", "Heather", "Ike", "Jane")
+    )
+  )
 
   ## Eigenvector-centrality, small stress-test
 
-  is.principal <- function(M, lambda, eps = 1e-12) {
-    abs(eigen(M)$values[1] - lambda) < eps
+  set.seed(20250907)
+
+  expect_principal <- function(M, lambda, eps = 1e-12) {
+    expect_lt(abs(eigen(M)$values[1] - lambda), eps)
   }
 
-  is.ev <- function(M, v, lambda, eps = 1e-12) {
-    max(abs(M %*% v - lambda * v)) < eps
+  expect_ev <- function(M, v, lambda, eps = 1e-12) {
+    expect_lt(max(abs(M %*% v - lambda * v)), eps)
   }
 
-  is.good <- function(M, v, lambda, eps = 1e-12) {
-    is.principal(M, lambda, eps) && is.ev(M, v, lambda, eps)
+  expect_good <- function(M, v, lambda, eps = 1e-12) {
+    expect_principal(M, lambda, eps)
+    expect_ev(M, v, lambda, eps)
   }
 
   for (i in 1:1000) {
     G <- sample_gnm(10, sample(1:20, 1))
     ev <- eigen_centrality(G)
-    expect_true(is.good(as_adjacency_matrix(G, sparse = FALSE), ev$vector, ev$value))
+    expect_good(
+      as_adjacency_matrix(G, sparse = FALSE),
+      ev$vector,
+      ev$value
+    )
   }
 })
 
@@ -587,7 +697,11 @@ test_that("spectrum() works for symmetric matrices", {
 
   rlang::local_options(lifecycle_verbosity = "warning")
   expect_warning(
-    e3 <- spectrum(g, which = list(howmany = 4, pos = "SA"), options = arpack_defaults)
+    e3 <- spectrum(
+      g,
+      which = list(howmany = 4, pos = "SA"),
+      options = arpack_defaults
+    )
   )
 })
 
@@ -596,7 +710,11 @@ test_that("arpack lifecycle warning", {
 
   f <- function(x, extra = NULL) x
   expect_warning(
-    res <- arpack(f, options = function() list(n = 10, nev = 2, ncv = 4), sym = TRUE)
+    res <- arpack(
+      f,
+      options = function() list(n = 10, nev = 2, ncv = 4),
+      sym = TRUE
+    )
   )
   expect_equal(res$values, c(1, 1))
 })
@@ -648,7 +766,11 @@ test_that("arpack works for non-symmetric matrices", {
   )
 
   f <- function(x, extra = NULL) A %*% x
-  res <- arpack(f, options = list(n = 10, nev = 3, ncv = 7, which = "LM"), sym = FALSE)
+  res <- arpack(
+    f,
+    options = list(n = 10, nev = 3, ncv = 7, which = "LM"),
+    sym = FALSE
+  )
   ## This is needed because they might return a different complex conjugate
   expect_equal(abs(res$values / eigen(A)$values[1:3]), c(1, 1, 1))
   expect_equal(
@@ -665,7 +787,11 @@ test_that("arpack works for non-symmetric matrices", {
   )
 
   f <- function(x, extra = NULL) A %*% x
-  res <- arpack(f, options = list(n = 10, nev = 4, ncv = 9, which = "LM"), sym = FALSE)
+  res <- arpack(
+    f,
+    options = list(n = 10, nev = 4, ncv = 9, which = "LM"),
+    sym = FALSE
+  )
   ## This is needed because they might return a different complex conjugate
   expect_equal(abs(res$values / eigen(A)$values[1:4]), rep(1, 4))
   expect_equal(
@@ -693,10 +819,24 @@ test_that("arpack works for non-symmetric matrices", {
 test_that("eigen_centrality() deprecated scale argument", {
   g <- make_ring(10, directed = FALSE)
   expect_snapshot({
-    eigen_centrality(g, scale = TRUE)
+    invisible(eigen_centrality(g, scale = TRUE))
   })
   # For some reason, this produces different outputs on Windows and macOS
   expect_snapshot({
     invisible(eigen_centrality(g, scale = FALSE))
   })
 })
+
+test_that("arpack() errors well", {
+  f <- function(x, extra = NULL) x
+  expect_snapshot(error = TRUE, {
+    arpack(f, options = list(nev = 2, ncv = 4), sym = TRUE)
+  })
+  expect_snapshot(error = TRUE, {
+    arpack(
+      f,
+      options = list(unknown_thing1 = 2, unknown_thing2 = 4),
+      sym = TRUE
+    )
+  })
+})
